# Autogenerated by get_module_idx.py

d = { 'settings': {'lib_path': 'nbdev_django'},
  'syms': { 'asgiref.sync': { 'asgiref.sync.async_to_sync': 'http://django.readthedocs.org/en/latest/topics/async.html#asgiref.sync.async_to_sync',
                              'asgiref.sync.sync_to_async': 'http://django.readthedocs.org/en/latest/topics/async.html#asgiref.sync.sync_to_async'},
            'django': { 'django.apps': 'http://django.readthedocs.org/en/latest/ref/applications.html#module-django.apps',
                        'django.db': 'http://django.readthedocs.org/en/latest/topics/db/index.html#module-django.db',
                        'django.dispatch': 'http://django.readthedocs.org/en/latest/topics/signals.html#module-django.dispatch',
                        'django.forms': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#module-django.forms',
                        'django.http': 'http://django.readthedocs.org/en/latest/ref/request-response.html#module-django.http',
                        'django.middleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.middleware',
                        'django.setup': 'http://django.readthedocs.org/en/latest/ref/applications.html#django.setup',
                        'django.shortcuts': 'http://django.readthedocs.org/en/latest/topics/http/shortcuts.html#module-django.shortcuts',
                        'django.template': 'http://django.readthedocs.org/en/latest/topics/templates.html#module-django.template',
                        'django.test': 'http://django.readthedocs.org/en/latest/topics/testing/overview.html#module-django.test',
                        'django.urls': 'http://django.readthedocs.org/en/latest/ref/urlresolvers.html#module-django.urls',
                        'django.utils': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils',
                        'django.views': 'http://django.readthedocs.org/en/latest/ref/views.html#module-django.views'},
            'django.apps': { 'django.apps.AppConfig': 'http://django.readthedocs.org/en/latest/ref/applications.html#django.apps.AppConfig',
                             'django.apps.AppConfig.get_model': 'http://django.readthedocs.org/en/latest/ref/applications.html#django.apps.AppConfig.get_model',
                             'django.apps.AppConfig.get_models': 'http://django.readthedocs.org/en/latest/ref/applications.html#django.apps.AppConfig.get_models',
                             'django.apps.AppConfig.ready': 'http://django.readthedocs.org/en/latest/ref/applications.html#django.apps.AppConfig.ready',
                             'django.apps.apps.get_app_config': 'http://django.readthedocs.org/en/latest/ref/applications.html#django.apps.apps.get_app_config',
                             'django.apps.apps.get_app_configs': 'http://django.readthedocs.org/en/latest/ref/applications.html#django.apps.apps.get_app_configs',
                             'django.apps.apps.get_model': 'http://django.readthedocs.org/en/latest/ref/applications.html#django.apps.apps.get_model',
                             'django.apps.apps.is_installed': 'http://django.readthedocs.org/en/latest/ref/applications.html#django.apps.apps.is_installed'},
            'django.conf': {'django.conf.urls': 'http://django.readthedocs.org/en/latest/ref/urls.html#module-django.conf.urls'},
            'django.conf.settings': { 'django.conf.settings.configure': 'http://django.readthedocs.org/en/latest/topics/settings.html#django.conf.settings.configure'},
            'django.conf.urls': {'django.conf.urls.i18n': 'http://django.readthedocs.org/en/latest/topics/i18n/translation.html#module-django.conf.urls.i18n'},
            'django.conf.urls.i18n': { 'django.conf.urls.i18n.i18n_patterns': 'http://django.readthedocs.org/en/latest/topics/i18n/translation.html#django.conf.urls.i18n.i18n_patterns'},
            'django.conf.urls.static': { 'django.conf.urls.static.static': 'http://django.readthedocs.org/en/latest/ref/urls.html#django.conf.urls.static.static'},
            'django.contrib': { 'django.contrib.admin': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#module-django.contrib.admin',
                                'django.contrib.admindocs': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/admindocs.html#module-django.contrib.admindocs',
                                'django.contrib.auth': 'http://django.readthedocs.org/en/latest/topics/auth/index.html#module-django.contrib.auth',
                                'django.contrib.contenttypes': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#module-django.contrib.contenttypes',
                                'django.contrib.flatpages': 'http://django.readthedocs.org/en/latest/ref/contrib/flatpages.html#module-django.contrib.flatpages',
                                'django.contrib.gis': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/index.html#module-django.contrib.gis',
                                'django.contrib.humanize': 'http://django.readthedocs.org/en/latest/ref/contrib/humanize.html#module-django.contrib.humanize',
                                'django.contrib.messages': 'http://django.readthedocs.org/en/latest/ref/contrib/messages.html#module-django.contrib.messages',
                                'django.contrib.postgres': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/index.html#module-django.contrib.postgres',
                                'django.contrib.redirects': 'http://django.readthedocs.org/en/latest/ref/contrib/redirects.html#module-django.contrib.redirects',
                                'django.contrib.sessions': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#module-django.contrib.sessions',
                                'django.contrib.sitemaps': 'http://django.readthedocs.org/en/latest/ref/contrib/sitemaps.html#module-django.contrib.sitemaps',
                                'django.contrib.sites': 'http://django.readthedocs.org/en/latest/ref/contrib/sites.html#module-django.contrib.sites',
                                'django.contrib.staticfiles': 'http://django.readthedocs.org/en/latest/ref/contrib/staticfiles.html#module-django.contrib.staticfiles',
                                'django.contrib.syndication': 'http://django.readthedocs.org/en/latest/ref/contrib/syndication.html#module-django.contrib.syndication'},
            'django.contrib.admin': { 'django.contrib.admin.AdminSite': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.AdminSite',
                                      'django.contrib.admin.AdminSite.add_action': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/actions.html#django.contrib.admin.AdminSite.add_action',
                                      'django.contrib.admin.AdminSite.disable_action': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/actions.html#django.contrib.admin.AdminSite.disable_action',
                                      'django.contrib.admin.AdminSite.each_context': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.AdminSite.each_context',
                                      'django.contrib.admin.AdminSite.get_app_list': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.AdminSite.get_app_list',
                                      'django.contrib.admin.AdminSite.has_permission': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.AdminSite.has_permission',
                                      'django.contrib.admin.AdminSite.register': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.AdminSite.register',
                                      'django.contrib.admin.AdminSite.unregister': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.AdminSite.unregister',
                                      'django.contrib.admin.InlineModelAdmin': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.InlineModelAdmin',
                                      'django.contrib.admin.InlineModelAdmin.get_extra': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.InlineModelAdmin.get_extra',
                                      'django.contrib.admin.InlineModelAdmin.get_formset': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.InlineModelAdmin.get_formset',
                                      'django.contrib.admin.InlineModelAdmin.get_max_num': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.InlineModelAdmin.get_max_num',
                                      'django.contrib.admin.InlineModelAdmin.get_min_num': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.InlineModelAdmin.get_min_num',
                                      'django.contrib.admin.InlineModelAdmin.has_add_permission': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.InlineModelAdmin.has_add_permission',
                                      'django.contrib.admin.InlineModelAdmin.has_change_permission': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.InlineModelAdmin.has_change_permission',
                                      'django.contrib.admin.InlineModelAdmin.has_delete_permission': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.InlineModelAdmin.has_delete_permission',
                                      'django.contrib.admin.ModelAdmin': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin',
                                      'django.contrib.admin.ModelAdmin.add_view': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.add_view',
                                      'django.contrib.admin.ModelAdmin.change_view': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.change_view',
                                      'django.contrib.admin.ModelAdmin.changelist_view': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.changelist_view',
                                      'django.contrib.admin.ModelAdmin.delete_model': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.delete_model',
                                      'django.contrib.admin.ModelAdmin.delete_queryset': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.delete_queryset',
                                      'django.contrib.admin.ModelAdmin.delete_view': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.delete_view',
                                      'django.contrib.admin.ModelAdmin.formfield_for_choice_field': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.formfield_for_choice_field',
                                      'django.contrib.admin.ModelAdmin.formfield_for_foreignkey': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.formfield_for_foreignkey',
                                      'django.contrib.admin.ModelAdmin.formfield_for_manytomany': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.formfield_for_manytomany',
                                      'django.contrib.admin.ModelAdmin.get_actions': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/actions.html#django.contrib.admin.ModelAdmin.get_actions',
                                      'django.contrib.admin.ModelAdmin.get_autocomplete_fields': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_autocomplete_fields',
                                      'django.contrib.admin.ModelAdmin.get_changeform_initial_data': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_changeform_initial_data',
                                      'django.contrib.admin.ModelAdmin.get_changelist': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_changelist',
                                      'django.contrib.admin.ModelAdmin.get_changelist_form': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_changelist_form',
                                      'django.contrib.admin.ModelAdmin.get_changelist_formset': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_changelist_formset',
                                      'django.contrib.admin.ModelAdmin.get_deleted_objects': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_deleted_objects',
                                      'django.contrib.admin.ModelAdmin.get_exclude': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_exclude',
                                      'django.contrib.admin.ModelAdmin.get_fields': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_fields',
                                      'django.contrib.admin.ModelAdmin.get_fieldsets': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_fieldsets',
                                      'django.contrib.admin.ModelAdmin.get_form': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_form',
                                      'django.contrib.admin.ModelAdmin.get_formset_kwargs': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_formset_kwargs',
                                      'django.contrib.admin.ModelAdmin.get_formsets_with_inlines': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_formsets_with_inlines',
                                      'django.contrib.admin.ModelAdmin.get_inline_instances': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_inline_instances',
                                      'django.contrib.admin.ModelAdmin.get_inlines': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_inlines',
                                      'django.contrib.admin.ModelAdmin.get_list_display': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_list_display',
                                      'django.contrib.admin.ModelAdmin.get_list_display_links': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_list_display_links',
                                      'django.contrib.admin.ModelAdmin.get_list_filter': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_list_filter',
                                      'django.contrib.admin.ModelAdmin.get_list_select_related': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_list_select_related',
                                      'django.contrib.admin.ModelAdmin.get_ordering': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_ordering',
                                      'django.contrib.admin.ModelAdmin.get_paginator': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_paginator',
                                      'django.contrib.admin.ModelAdmin.get_prepopulated_fields': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_prepopulated_fields',
                                      'django.contrib.admin.ModelAdmin.get_queryset': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_queryset',
                                      'django.contrib.admin.ModelAdmin.get_readonly_fields': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_readonly_fields',
                                      'django.contrib.admin.ModelAdmin.get_search_fields': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_search_fields',
                                      'django.contrib.admin.ModelAdmin.get_search_results': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_search_results',
                                      'django.contrib.admin.ModelAdmin.get_sortable_by': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_sortable_by',
                                      'django.contrib.admin.ModelAdmin.get_urls': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.get_urls',
                                      'django.contrib.admin.ModelAdmin.has_add_permission': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.has_add_permission',
                                      'django.contrib.admin.ModelAdmin.has_change_permission': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.has_change_permission',
                                      'django.contrib.admin.ModelAdmin.has_delete_permission': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.has_delete_permission',
                                      'django.contrib.admin.ModelAdmin.has_module_permission': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.has_module_permission',
                                      'django.contrib.admin.ModelAdmin.has_view_permission': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.has_view_permission',
                                      'django.contrib.admin.ModelAdmin.history_view': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.history_view',
                                      'django.contrib.admin.ModelAdmin.lookup_allowed': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.lookup_allowed',
                                      'django.contrib.admin.ModelAdmin.message_user': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.message_user',
                                      'django.contrib.admin.ModelAdmin.response_add': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.response_add',
                                      'django.contrib.admin.ModelAdmin.response_change': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.response_change',
                                      'django.contrib.admin.ModelAdmin.response_delete': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.response_delete',
                                      'django.contrib.admin.ModelAdmin.save_formset': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.save_formset',
                                      'django.contrib.admin.ModelAdmin.save_model': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.save_model',
                                      'django.contrib.admin.ModelAdmin.save_related': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.ModelAdmin.save_related',
                                      'django.contrib.admin.StackedInline': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.StackedInline',
                                      'django.contrib.admin.TabularInline': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.TabularInline',
                                      'django.contrib.admin.action': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/actions.html#django.contrib.admin.action',
                                      'django.contrib.admin.autodiscover': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.autodiscover',
                                      'django.contrib.admin.display': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.display',
                                      'django.contrib.admin.register': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.register'},
            'django.contrib.admin.apps': { 'django.contrib.admin.apps.AdminConfig': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.apps.AdminConfig',
                                           'django.contrib.admin.apps.SimpleAdminConfig': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.apps.SimpleAdminConfig'},
            'django.contrib.admin.models': { 'django.contrib.admin.models.LogEntry': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.models.LogEntry',
                                             'django.contrib.admin.models.LogEntry.get_change_message': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.models.LogEntry.get_change_message',
                                             'django.contrib.admin.models.LogEntry.get_edited_object': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.models.LogEntry.get_edited_object'},
            'django.contrib.admin.views.decorators': { 'django.contrib.admin.views.decorators.staff_member_required': 'http://django.readthedocs.org/en/latest/ref/contrib/admin/index.html#django.contrib.admin.views.decorators.staff_member_required'},
            'django.contrib.auth': { 'django.contrib.auth.authenticate': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.authenticate',
                                     'django.contrib.auth.backends': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#module-django.contrib.auth.backends',
                                     'django.contrib.auth.forms': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#module-django.contrib.auth.forms',
                                     'django.contrib.auth.get_user': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.get_user',
                                     'django.contrib.auth.get_user_model': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.get_user_model',
                                     'django.contrib.auth.hashers': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#module-django.contrib.auth.hashers',
                                     'django.contrib.auth.login': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.login',
                                     'django.contrib.auth.logout': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.logout',
                                     'django.contrib.auth.middleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.contrib.auth.middleware',
                                     'django.contrib.auth.password_validation': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#module-django.contrib.auth.password_validation',
                                     'django.contrib.auth.signals': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#module-django.contrib.auth.signals',
                                     'django.contrib.auth.update_session_auth_hash': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.update_session_auth_hash',
                                     'django.contrib.auth.views': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#module-django.contrib.auth.views'},
            'django.contrib.auth.backends': { 'django.contrib.auth.backends.AllowAllUsersModelBackend': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.AllowAllUsersModelBackend',
                                              'django.contrib.auth.backends.AllowAllUsersRemoteUserBackend': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.AllowAllUsersRemoteUserBackend',
                                              'django.contrib.auth.backends.BaseBackend': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.BaseBackend',
                                              'django.contrib.auth.backends.BaseBackend.get_all_permissions': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.BaseBackend.get_all_permissions',
                                              'django.contrib.auth.backends.BaseBackend.get_group_permissions': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.BaseBackend.get_group_permissions',
                                              'django.contrib.auth.backends.BaseBackend.get_user_permissions': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.BaseBackend.get_user_permissions',
                                              'django.contrib.auth.backends.BaseBackend.has_perm': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.BaseBackend.has_perm',
                                              'django.contrib.auth.backends.ModelBackend': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.ModelBackend',
                                              'django.contrib.auth.backends.ModelBackend.authenticate': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.ModelBackend.authenticate',
                                              'django.contrib.auth.backends.ModelBackend.get_all_permissions': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.ModelBackend.get_all_permissions',
                                              'django.contrib.auth.backends.ModelBackend.get_group_permissions': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.ModelBackend.get_group_permissions',
                                              'django.contrib.auth.backends.ModelBackend.get_user_permissions': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.ModelBackend.get_user_permissions',
                                              'django.contrib.auth.backends.ModelBackend.has_module_perms': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.ModelBackend.has_module_perms',
                                              'django.contrib.auth.backends.ModelBackend.has_perm': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.ModelBackend.has_perm',
                                              'django.contrib.auth.backends.ModelBackend.user_can_authenticate': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.ModelBackend.user_can_authenticate',
                                              'django.contrib.auth.backends.ModelBackend.with_perm': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.ModelBackend.with_perm',
                                              'django.contrib.auth.backends.RemoteUserBackend': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.RemoteUserBackend',
                                              'django.contrib.auth.backends.RemoteUserBackend.authenticate': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.RemoteUserBackend.authenticate',
                                              'django.contrib.auth.backends.RemoteUserBackend.clean_username': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.RemoteUserBackend.clean_username',
                                              'django.contrib.auth.backends.RemoteUserBackend.configure_user': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.RemoteUserBackend.configure_user',
                                              'django.contrib.auth.backends.RemoteUserBackend.user_can_authenticate': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.backends.RemoteUserBackend.user_can_authenticate'},
            'django.contrib.auth.context_processors': { 'django.contrib.auth.context_processors.auth': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.contrib.auth.context_processors.auth'},
            'django.contrib.auth.decorators': { 'django.contrib.auth.decorators.login_required': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.decorators.login_required',
                                                'django.contrib.auth.decorators.permission_required': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.decorators.permission_required',
                                                'django.contrib.auth.decorators.user_passes_test': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.decorators.user_passes_test'},
            'django.contrib.auth.forms': { 'django.contrib.auth.forms.AdminPasswordChangeForm': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.forms.AdminPasswordChangeForm',
                                           'django.contrib.auth.forms.AuthenticationForm': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.forms.AuthenticationForm',
                                           'django.contrib.auth.forms.AuthenticationForm.confirm_login_allowed': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.forms.AuthenticationForm.confirm_login_allowed',
                                           'django.contrib.auth.forms.PasswordChangeForm': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.forms.PasswordChangeForm',
                                           'django.contrib.auth.forms.PasswordResetForm': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.forms.PasswordResetForm',
                                           'django.contrib.auth.forms.PasswordResetForm.send_mail': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.forms.PasswordResetForm.send_mail',
                                           'django.contrib.auth.forms.SetPasswordForm': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.forms.SetPasswordForm',
                                           'django.contrib.auth.forms.UserChangeForm': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.forms.UserChangeForm',
                                           'django.contrib.auth.forms.UserCreationForm': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.forms.UserCreationForm'},
            'django.contrib.auth.hashers': { 'django.contrib.auth.hashers.check_password': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.hashers.check_password',
                                             'django.contrib.auth.hashers.is_password_usable': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.hashers.is_password_usable',
                                             'django.contrib.auth.hashers.make_password': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.hashers.make_password'},
            'django.contrib.auth.middleware': { 'django.contrib.auth.middleware.AuthenticationMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.contrib.auth.middleware.AuthenticationMiddleware',
                                                'django.contrib.auth.middleware.PersistentRemoteUserMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.contrib.auth.middleware.PersistentRemoteUserMiddleware',
                                                'django.contrib.auth.middleware.RemoteUserMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.contrib.auth.middleware.RemoteUserMiddleware'},
            'django.contrib.auth.mixins': { 'django.contrib.auth.mixins.AccessMixin': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.AccessMixin',
                                            'django.contrib.auth.mixins.AccessMixin.get_login_url': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.AccessMixin.get_login_url',
                                            'django.contrib.auth.mixins.AccessMixin.get_permission_denied_message': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.AccessMixin.get_permission_denied_message',
                                            'django.contrib.auth.mixins.AccessMixin.get_redirect_field_name': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.AccessMixin.get_redirect_field_name',
                                            'django.contrib.auth.mixins.AccessMixin.handle_no_permission': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.AccessMixin.handle_no_permission',
                                            'django.contrib.auth.mixins.LoginRequiredMixin': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.LoginRequiredMixin',
                                            'django.contrib.auth.mixins.PermissionRequiredMixin': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.PermissionRequiredMixin',
                                            'django.contrib.auth.mixins.PermissionRequiredMixin.get_permission_required': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.PermissionRequiredMixin.get_permission_required',
                                            'django.contrib.auth.mixins.PermissionRequiredMixin.has_permission': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.PermissionRequiredMixin.has_permission',
                                            'django.contrib.auth.mixins.UserPassesTestMixin': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.UserPassesTestMixin',
                                            'django.contrib.auth.mixins.UserPassesTestMixin.get_test_func': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.UserPassesTestMixin.get_test_func',
                                            'django.contrib.auth.mixins.UserPassesTestMixin.test_func': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.mixins.UserPassesTestMixin.test_func'},
            'django.contrib.auth.models': { 'django.contrib.auth.models.AbstractBaseUser': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractBaseUser',
                                            'django.contrib.auth.models.AbstractBaseUser.check_password': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractBaseUser.check_password',
                                            'django.contrib.auth.models.AbstractBaseUser.clean': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractBaseUser.clean',
                                            'django.contrib.auth.models.AbstractBaseUser.get_email_field_name': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractBaseUser.get_email_field_name',
                                            'django.contrib.auth.models.AbstractBaseUser.get_session_auth_hash': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractBaseUser.get_session_auth_hash',
                                            'django.contrib.auth.models.AbstractBaseUser.get_username': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractBaseUser.get_username',
                                            'django.contrib.auth.models.AbstractBaseUser.has_usable_password': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractBaseUser.has_usable_password',
                                            'django.contrib.auth.models.AbstractBaseUser.normalize_username': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractBaseUser.normalize_username',
                                            'django.contrib.auth.models.AbstractBaseUser.set_password': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractBaseUser.set_password',
                                            'django.contrib.auth.models.AbstractBaseUser.set_unusable_password': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractBaseUser.set_unusable_password',
                                            'django.contrib.auth.models.AbstractUser': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractUser',
                                            'django.contrib.auth.models.AbstractUser.clean': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.AbstractUser.clean',
                                            'django.contrib.auth.models.AnonymousUser': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.AnonymousUser',
                                            'django.contrib.auth.models.BaseUserManager': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.BaseUserManager',
                                            'django.contrib.auth.models.BaseUserManager.get_by_natural_key': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.BaseUserManager.get_by_natural_key',
                                            'django.contrib.auth.models.BaseUserManager.make_random_password': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.BaseUserManager.make_random_password',
                                            'django.contrib.auth.models.BaseUserManager.normalize_email': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.BaseUserManager.normalize_email',
                                            'django.contrib.auth.models.CustomUser': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.CustomUser',
                                            'django.contrib.auth.models.CustomUser.get_full_name': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.CustomUser.get_full_name',
                                            'django.contrib.auth.models.CustomUser.get_short_name': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.CustomUser.get_short_name',
                                            'django.contrib.auth.models.CustomUserManager': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.CustomUserManager',
                                            'django.contrib.auth.models.CustomUserManager.create_superuser': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.CustomUserManager.create_superuser',
                                            'django.contrib.auth.models.CustomUserManager.create_user': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.CustomUserManager.create_user',
                                            'django.contrib.auth.models.Group': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.Group',
                                            'django.contrib.auth.models.Permission': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.Permission',
                                            'django.contrib.auth.models.PermissionsMixin': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.PermissionsMixin',
                                            'django.contrib.auth.models.PermissionsMixin.get_all_permissions': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.PermissionsMixin.get_all_permissions',
                                            'django.contrib.auth.models.PermissionsMixin.get_group_permissions': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.PermissionsMixin.get_group_permissions',
                                            'django.contrib.auth.models.PermissionsMixin.get_user_permissions': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.PermissionsMixin.get_user_permissions',
                                            'django.contrib.auth.models.PermissionsMixin.has_module_perms': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.PermissionsMixin.has_module_perms',
                                            'django.contrib.auth.models.PermissionsMixin.has_perm': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.PermissionsMixin.has_perm',
                                            'django.contrib.auth.models.PermissionsMixin.has_perms': 'http://django.readthedocs.org/en/latest/topics/auth/customizing.html#django.contrib.auth.models.PermissionsMixin.has_perms',
                                            'django.contrib.auth.models.User': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User',
                                            'django.contrib.auth.models.User.check_password': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.check_password',
                                            'django.contrib.auth.models.User.email_user': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.email_user',
                                            'django.contrib.auth.models.User.get_all_permissions': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.get_all_permissions',
                                            'django.contrib.auth.models.User.get_full_name': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.get_full_name',
                                            'django.contrib.auth.models.User.get_group_permissions': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.get_group_permissions',
                                            'django.contrib.auth.models.User.get_short_name': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.get_short_name',
                                            'django.contrib.auth.models.User.get_user_permissions': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.get_user_permissions',
                                            'django.contrib.auth.models.User.get_username': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.get_username',
                                            'django.contrib.auth.models.User.has_module_perms': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.has_module_perms',
                                            'django.contrib.auth.models.User.has_perm': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.has_perm',
                                            'django.contrib.auth.models.User.has_perms': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.has_perms',
                                            'django.contrib.auth.models.User.has_usable_password': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.has_usable_password',
                                            'django.contrib.auth.models.User.set_password': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.set_password',
                                            'django.contrib.auth.models.User.set_unusable_password': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.User.set_unusable_password',
                                            'django.contrib.auth.models.UserManager': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.UserManager',
                                            'django.contrib.auth.models.UserManager.create_superuser': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.UserManager.create_superuser',
                                            'django.contrib.auth.models.UserManager.create_user': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.UserManager.create_user',
                                            'django.contrib.auth.models.UserManager.with_perm': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.models.UserManager.with_perm'},
            'django.contrib.auth.password_validation': { 'django.contrib.auth.password_validation.CommonPasswordValidator': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.password_validation.CommonPasswordValidator',
                                                         'django.contrib.auth.password_validation.MinimumLengthValidator': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.password_validation.MinimumLengthValidator',
                                                         'django.contrib.auth.password_validation.NumericPasswordValidator': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.password_validation.NumericPasswordValidator',
                                                         'django.contrib.auth.password_validation.UserAttributeSimilarityValidator': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
                                                         'django.contrib.auth.password_validation.get_password_validators': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.password_validation.get_password_validators',
                                                         'django.contrib.auth.password_validation.password_changed': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.password_validation.password_changed',
                                                         'django.contrib.auth.password_validation.password_validators_help_text_html': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.password_validation.password_validators_help_text_html',
                                                         'django.contrib.auth.password_validation.password_validators_help_texts': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.password_validation.password_validators_help_texts',
                                                         'django.contrib.auth.password_validation.validate_password': 'http://django.readthedocs.org/en/latest/topics/auth/passwords.html#django.contrib.auth.password_validation.validate_password'},
            'django.contrib.auth.validators': { 'django.contrib.auth.validators.ASCIIUsernameValidator': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.validators.ASCIIUsernameValidator',
                                                'django.contrib.auth.validators.UnicodeUsernameValidator': 'http://django.readthedocs.org/en/latest/ref/contrib/auth.html#django.contrib.auth.validators.UnicodeUsernameValidator'},
            'django.contrib.auth.views': { 'django.contrib.auth.views.LoginView': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.LoginView',
                                           'django.contrib.auth.views.LoginView.get_default_redirect_url': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.LoginView.get_default_redirect_url',
                                           'django.contrib.auth.views.LogoutView': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.LogoutView',
                                           'django.contrib.auth.views.PasswordChangeDoneView': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.PasswordChangeDoneView',
                                           'django.contrib.auth.views.PasswordChangeView': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.PasswordChangeView',
                                           'django.contrib.auth.views.PasswordResetCompleteView': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.PasswordResetCompleteView',
                                           'django.contrib.auth.views.PasswordResetConfirmView': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.PasswordResetConfirmView',
                                           'django.contrib.auth.views.PasswordResetDoneView': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.PasswordResetDoneView',
                                           'django.contrib.auth.views.PasswordResetView': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.PasswordResetView',
                                           'django.contrib.auth.views.logout_then_login': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.logout_then_login',
                                           'django.contrib.auth.views.redirect_to_login': 'http://django.readthedocs.org/en/latest/topics/auth/default.html#django.contrib.auth.views.redirect_to_login'},
            'django.contrib.contenttypes': { 'django.contrib.contenttypes.admin': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#module-django.contrib.contenttypes.admin',
                                             'django.contrib.contenttypes.fields': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#module-django.contrib.contenttypes.fields',
                                             'django.contrib.contenttypes.forms': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#module-django.contrib.contenttypes.forms'},
            'django.contrib.contenttypes.admin': { 'django.contrib.contenttypes.admin.GenericInlineModelAdmin': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.admin.GenericInlineModelAdmin',
                                                   'django.contrib.contenttypes.admin.GenericStackedInline': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.admin.GenericStackedInline',
                                                   'django.contrib.contenttypes.admin.GenericTabularInline': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.admin.GenericTabularInline'},
            'django.contrib.contenttypes.fields': { 'django.contrib.contenttypes.fields.GenericForeignKey': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.fields.GenericForeignKey',
                                                    'django.contrib.contenttypes.fields.GenericRelation': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.fields.GenericRelation'},
            'django.contrib.contenttypes.forms': { 'django.contrib.contenttypes.forms.BaseGenericInlineFormSet': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.forms.BaseGenericInlineFormSet',
                                                   'django.contrib.contenttypes.forms.generic_inlineformset_factory': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.forms.generic_inlineformset_factory'},
            'django.contrib.contenttypes.models': { 'django.contrib.contenttypes.models.ContentType': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.models.ContentType',
                                                    'django.contrib.contenttypes.models.ContentType.get_object_for_this_type': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.models.ContentType.get_object_for_this_type',
                                                    'django.contrib.contenttypes.models.ContentType.model_class': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.models.ContentType.model_class',
                                                    'django.contrib.contenttypes.models.ContentTypeManager': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.models.ContentTypeManager',
                                                    'django.contrib.contenttypes.models.ContentTypeManager.clear_cache': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.models.ContentTypeManager.clear_cache',
                                                    'django.contrib.contenttypes.models.ContentTypeManager.get_by_natural_key': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.models.ContentTypeManager.get_by_natural_key',
                                                    'django.contrib.contenttypes.models.ContentTypeManager.get_for_id': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.models.ContentTypeManager.get_for_id',
                                                    'django.contrib.contenttypes.models.ContentTypeManager.get_for_model': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.models.ContentTypeManager.get_for_model',
                                                    'django.contrib.contenttypes.models.ContentTypeManager.get_for_models': 'http://django.readthedocs.org/en/latest/ref/contrib/contenttypes.html#django.contrib.contenttypes.models.ContentTypeManager.get_for_models'},
            'django.contrib.flatpages.middleware': { 'django.contrib.flatpages.middleware.FlatpageFallbackMiddleware': 'http://django.readthedocs.org/en/latest/ref/contrib/flatpages.html#django.contrib.flatpages.middleware.FlatpageFallbackMiddleware'},
            'django.contrib.flatpages.models': { 'django.contrib.flatpages.models.FlatPage': 'http://django.readthedocs.org/en/latest/ref/contrib/flatpages.html#django.contrib.flatpages.models.FlatPage'},
            'django.contrib.flatpages.sitemaps': { 'django.contrib.flatpages.sitemaps.FlatPageSitemap': 'http://django.readthedocs.org/en/latest/ref/contrib/flatpages.html#django.contrib.flatpages.sitemaps.FlatPageSitemap'},
            'django.contrib.gis': { 'django.contrib.gis.admin': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/admin.html#module-django.contrib.gis.admin',
                                    'django.contrib.gis.feeds': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/feeds.html#module-django.contrib.gis.feeds',
                                    'django.contrib.gis.forms': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#module-django.contrib.gis.forms',
                                    'django.contrib.gis.gdal': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#module-django.contrib.gis.gdal',
                                    'django.contrib.gis.geoip2': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#module-django.contrib.gis.geoip2',
                                    'django.contrib.gis.geos': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#module-django.contrib.gis.geos',
                                    'django.contrib.gis.measure': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/measure.html#module-django.contrib.gis.measure',
                                    'django.contrib.gis.utils': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/utils.html#module-django.contrib.gis.utils'},
            'django.contrib.gis.admin': { 'django.contrib.gis.admin.GISModelAdmin': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/admin.html#django.contrib.gis.admin.GISModelAdmin',
                                          'django.contrib.gis.admin.GeoModelAdmin': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/admin.html#django.contrib.gis.admin.GeoModelAdmin',
                                          'django.contrib.gis.admin.OSMGeoAdmin': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/admin.html#django.contrib.gis.admin.OSMGeoAdmin'},
            'django.contrib.gis.db': { 'django.contrib.gis.db.backends': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/db-api.html#module-django.contrib.gis.db.backends',
                                       'django.contrib.gis.db.models': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/model-api.html#module-django.contrib.gis.db.models'},
            'django.contrib.gis.db.models': { 'django.contrib.gis.db.models.Collect': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoquerysets.html#django.contrib.gis.db.models.Collect',
                                              'django.contrib.gis.db.models.Extent': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoquerysets.html#django.contrib.gis.db.models.Extent',
                                              'django.contrib.gis.db.models.Extent3D': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoquerysets.html#django.contrib.gis.db.models.Extent3D',
                                              'django.contrib.gis.db.models.GeometryCollectionField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/model-api.html#django.contrib.gis.db.models.GeometryCollectionField',
                                              'django.contrib.gis.db.models.GeometryField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/model-api.html#django.contrib.gis.db.models.GeometryField',
                                              'django.contrib.gis.db.models.LineStringField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/model-api.html#django.contrib.gis.db.models.LineStringField',
                                              'django.contrib.gis.db.models.MakeLine': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoquerysets.html#django.contrib.gis.db.models.MakeLine',
                                              'django.contrib.gis.db.models.MultiLineStringField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/model-api.html#django.contrib.gis.db.models.MultiLineStringField',
                                              'django.contrib.gis.db.models.MultiPointField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/model-api.html#django.contrib.gis.db.models.MultiPointField',
                                              'django.contrib.gis.db.models.MultiPolygonField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/model-api.html#django.contrib.gis.db.models.MultiPolygonField',
                                              'django.contrib.gis.db.models.PointField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/model-api.html#django.contrib.gis.db.models.PointField',
                                              'django.contrib.gis.db.models.PolygonField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/model-api.html#django.contrib.gis.db.models.PolygonField',
                                              'django.contrib.gis.db.models.RasterField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/model-api.html#django.contrib.gis.db.models.RasterField',
                                              'django.contrib.gis.db.models.Union': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoquerysets.html#django.contrib.gis.db.models.Union',
                                              'django.contrib.gis.db.models.functions': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#module-django.contrib.gis.db.models.functions'},
            'django.contrib.gis.db.models.functions': { 'django.contrib.gis.db.models.functions.Area': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Area',
                                                        'django.contrib.gis.db.models.functions.AsGML': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.AsGML',
                                                        'django.contrib.gis.db.models.functions.AsGeoJSON': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.AsGeoJSON',
                                                        'django.contrib.gis.db.models.functions.AsKML': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.AsKML',
                                                        'django.contrib.gis.db.models.functions.AsSVG': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.AsSVG',
                                                        'django.contrib.gis.db.models.functions.AsWKB': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.AsWKB',
                                                        'django.contrib.gis.db.models.functions.AsWKT': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.AsWKT',
                                                        'django.contrib.gis.db.models.functions.Azimuth': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Azimuth',
                                                        'django.contrib.gis.db.models.functions.BoundingCircle': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.BoundingCircle',
                                                        'django.contrib.gis.db.models.functions.Centroid': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Centroid',
                                                        'django.contrib.gis.db.models.functions.Difference': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Difference',
                                                        'django.contrib.gis.db.models.functions.Distance': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Distance',
                                                        'django.contrib.gis.db.models.functions.Envelope': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Envelope',
                                                        'django.contrib.gis.db.models.functions.ForcePolygonCW': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.ForcePolygonCW',
                                                        'django.contrib.gis.db.models.functions.GeoHash': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.GeoHash',
                                                        'django.contrib.gis.db.models.functions.GeometryDistance': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.GeometryDistance',
                                                        'django.contrib.gis.db.models.functions.Intersection': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Intersection',
                                                        'django.contrib.gis.db.models.functions.IsValid': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.IsValid',
                                                        'django.contrib.gis.db.models.functions.Length': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Length',
                                                        'django.contrib.gis.db.models.functions.LineLocatePoint': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.LineLocatePoint',
                                                        'django.contrib.gis.db.models.functions.MakeValid': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.MakeValid',
                                                        'django.contrib.gis.db.models.functions.MemSize': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.MemSize',
                                                        'django.contrib.gis.db.models.functions.NumGeometries': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.NumGeometries',
                                                        'django.contrib.gis.db.models.functions.NumPoints': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.NumPoints',
                                                        'django.contrib.gis.db.models.functions.Perimeter': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Perimeter',
                                                        'django.contrib.gis.db.models.functions.PointOnSurface': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.PointOnSurface',
                                                        'django.contrib.gis.db.models.functions.Reverse': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Reverse',
                                                        'django.contrib.gis.db.models.functions.Scale': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Scale',
                                                        'django.contrib.gis.db.models.functions.SnapToGrid': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.SnapToGrid',
                                                        'django.contrib.gis.db.models.functions.SymDifference': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.SymDifference',
                                                        'django.contrib.gis.db.models.functions.Transform': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Transform',
                                                        'django.contrib.gis.db.models.functions.Translate': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Translate',
                                                        'django.contrib.gis.db.models.functions.Union': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/functions.html#django.contrib.gis.db.models.functions.Union'},
            'django.contrib.gis.feeds': { 'django.contrib.gis.feeds.Feed': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/feeds.html#django.contrib.gis.feeds.Feed',
                                          'django.contrib.gis.feeds.Feed.geometry': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/feeds.html#django.contrib.gis.feeds.Feed.geometry',
                                          'django.contrib.gis.feeds.Feed.item_geometry': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/feeds.html#django.contrib.gis.feeds.Feed.item_geometry',
                                          'django.contrib.gis.feeds.GeoAtom1Feed': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/feeds.html#django.contrib.gis.feeds.GeoAtom1Feed',
                                          'django.contrib.gis.feeds.GeoRSSFeed': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/feeds.html#django.contrib.gis.feeds.GeoRSSFeed',
                                          'django.contrib.gis.feeds.W3CGeoFeed': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/feeds.html#django.contrib.gis.feeds.W3CGeoFeed'},
            'django.contrib.gis.forms': { 'django.contrib.gis.forms.GeometryCollectionField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.GeometryCollectionField',
                                          'django.contrib.gis.forms.GeometryField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.GeometryField',
                                          'django.contrib.gis.forms.LineStringField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.LineStringField',
                                          'django.contrib.gis.forms.MultiLineStringField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.MultiLineStringField',
                                          'django.contrib.gis.forms.MultiPointField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.MultiPointField',
                                          'django.contrib.gis.forms.MultiPolygonField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.MultiPolygonField',
                                          'django.contrib.gis.forms.PointField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.PointField',
                                          'django.contrib.gis.forms.PolygonField': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.PolygonField',
                                          'django.contrib.gis.forms.widgets': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#module-django.contrib.gis.forms.widgets'},
            'django.contrib.gis.forms.widgets': { 'django.contrib.gis.forms.widgets.BaseGeometryWidget': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.widgets.BaseGeometryWidget',
                                                  'django.contrib.gis.forms.widgets.OSMWidget': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.widgets.OSMWidget',
                                                  'django.contrib.gis.forms.widgets.OpenLayersWidget': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/forms-api.html#django.contrib.gis.forms.widgets.OpenLayersWidget'},
            'django.contrib.gis.gdal': { 'django.contrib.gis.gdal.CoordTransform': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.CoordTransform',
                                         'django.contrib.gis.gdal.DataSource': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.DataSource',
                                         'django.contrib.gis.gdal.Driver': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Driver',
                                         'django.contrib.gis.gdal.Envelope': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Envelope',
                                         'django.contrib.gis.gdal.Envelope.expand_to_include': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Envelope.expand_to_include',
                                         'django.contrib.gis.gdal.Feature': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Feature',
                                         'django.contrib.gis.gdal.Field': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Field',
                                         'django.contrib.gis.gdal.Field.as_datetime': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Field.as_datetime',
                                         'django.contrib.gis.gdal.Field.as_double': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Field.as_double',
                                         'django.contrib.gis.gdal.Field.as_int': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Field.as_int',
                                         'django.contrib.gis.gdal.Field.as_string': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Field.as_string',
                                         'django.contrib.gis.gdal.GDALBand': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.GDALBand',
                                         'django.contrib.gis.gdal.GDALBand.color_interp': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.GDALBand.color_interp',
                                         'django.contrib.gis.gdal.GDALBand.data': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.GDALBand.data',
                                         'django.contrib.gis.gdal.GDALBand.datatype': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.GDALBand.datatype',
                                         'django.contrib.gis.gdal.GDALBand.statistics': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.GDALBand.statistics',
                                         'django.contrib.gis.gdal.GDALRaster': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.GDALRaster',
                                         'django.contrib.gis.gdal.GDALRaster.transform': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.GDALRaster.transform',
                                         'django.contrib.gis.gdal.GDALRaster.warp': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.GDALRaster.warp',
                                         'django.contrib.gis.gdal.GeometryCollection': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.GeometryCollection',
                                         'django.contrib.gis.gdal.GeometryCollection.add': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.GeometryCollection.add',
                                         'django.contrib.gis.gdal.Layer': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Layer',
                                         'django.contrib.gis.gdal.Layer.get_fields': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Layer.get_fields',
                                         'django.contrib.gis.gdal.Layer.get_geoms': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Layer.get_geoms',
                                         'django.contrib.gis.gdal.Layer.test_capability': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Layer.test_capability',
                                         'django.contrib.gis.gdal.LineString': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.LineString',
                                         'django.contrib.gis.gdal.OGRGeomType': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeomType',
                                         'django.contrib.gis.gdal.OGRGeometry': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry',
                                         'django.contrib.gis.gdal.OGRGeometry.__getitem__': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.__getitem__',
                                         'django.contrib.gis.gdal.OGRGeometry.__iter__': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.__iter__',
                                         'django.contrib.gis.gdal.OGRGeometry.__len__': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.__len__',
                                         'django.contrib.gis.gdal.OGRGeometry.boundary': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.boundary',
                                         'django.contrib.gis.gdal.OGRGeometry.clone': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.clone',
                                         'django.contrib.gis.gdal.OGRGeometry.close_rings': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.close_rings',
                                         'django.contrib.gis.gdal.OGRGeometry.contains': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.contains',
                                         'django.contrib.gis.gdal.OGRGeometry.crosses': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.crosses',
                                         'django.contrib.gis.gdal.OGRGeometry.difference': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.difference',
                                         'django.contrib.gis.gdal.OGRGeometry.disjoint': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.disjoint',
                                         'django.contrib.gis.gdal.OGRGeometry.equals': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.equals',
                                         'django.contrib.gis.gdal.OGRGeometry.from_bbox': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.from_bbox',
                                         'django.contrib.gis.gdal.OGRGeometry.from_gml': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.from_gml',
                                         'django.contrib.gis.gdal.OGRGeometry.intersection': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.intersection',
                                         'django.contrib.gis.gdal.OGRGeometry.intersects': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.intersects',
                                         'django.contrib.gis.gdal.OGRGeometry.overlaps': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.overlaps',
                                         'django.contrib.gis.gdal.OGRGeometry.sym_difference': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.sym_difference',
                                         'django.contrib.gis.gdal.OGRGeometry.touches': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.touches',
                                         'django.contrib.gis.gdal.OGRGeometry.transform': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.transform',
                                         'django.contrib.gis.gdal.OGRGeometry.union': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.union',
                                         'django.contrib.gis.gdal.OGRGeometry.within': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.OGRGeometry.within',
                                         'django.contrib.gis.gdal.Point': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Point',
                                         'django.contrib.gis.gdal.Polygon': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.Polygon',
                                         'django.contrib.gis.gdal.SpatialReference': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference',
                                         'django.contrib.gis.gdal.SpatialReference.__getitem__': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.__getitem__',
                                         'django.contrib.gis.gdal.SpatialReference.attr_value': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.attr_value',
                                         'django.contrib.gis.gdal.SpatialReference.auth_code': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.auth_code',
                                         'django.contrib.gis.gdal.SpatialReference.auth_name': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.auth_name',
                                         'django.contrib.gis.gdal.SpatialReference.clone': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.clone',
                                         'django.contrib.gis.gdal.SpatialReference.from_esri': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.from_esri',
                                         'django.contrib.gis.gdal.SpatialReference.identify_epsg': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.identify_epsg',
                                         'django.contrib.gis.gdal.SpatialReference.import_epsg': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.import_epsg',
                                         'django.contrib.gis.gdal.SpatialReference.import_proj': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.import_proj',
                                         'django.contrib.gis.gdal.SpatialReference.import_user_input': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.import_user_input',
                                         'django.contrib.gis.gdal.SpatialReference.import_wkt': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.import_wkt',
                                         'django.contrib.gis.gdal.SpatialReference.import_xml': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.import_xml',
                                         'django.contrib.gis.gdal.SpatialReference.to_esri': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.to_esri',
                                         'django.contrib.gis.gdal.SpatialReference.validate': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/gdal.html#django.contrib.gis.gdal.SpatialReference.validate'},
            'django.contrib.gis.geoip2': { 'django.contrib.gis.geoip2.GeoIP2': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#django.contrib.gis.geoip2.GeoIP2',
                                           'django.contrib.gis.geoip2.GeoIP2.city': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#django.contrib.gis.geoip2.GeoIP2.city',
                                           'django.contrib.gis.geoip2.GeoIP2.coords': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#django.contrib.gis.geoip2.GeoIP2.coords',
                                           'django.contrib.gis.geoip2.GeoIP2.country': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#django.contrib.gis.geoip2.GeoIP2.country',
                                           'django.contrib.gis.geoip2.GeoIP2.country_code': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#django.contrib.gis.geoip2.GeoIP2.country_code',
                                           'django.contrib.gis.geoip2.GeoIP2.country_name': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#django.contrib.gis.geoip2.GeoIP2.country_name',
                                           'django.contrib.gis.geoip2.GeoIP2.geos': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#django.contrib.gis.geoip2.GeoIP2.geos',
                                           'django.contrib.gis.geoip2.GeoIP2.lat_lon': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#django.contrib.gis.geoip2.GeoIP2.lat_lon',
                                           'django.contrib.gis.geoip2.GeoIP2.lon_lat': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#django.contrib.gis.geoip2.GeoIP2.lon_lat',
                                           'django.contrib.gis.geoip2.GeoIP2.open': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geoip2.html#django.contrib.gis.geoip2.GeoIP2.open'},
            'django.contrib.gis.geos': { 'django.contrib.gis.geos.GEOSGeometry': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry',
                                         'django.contrib.gis.geos.GEOSGeometry.buffer': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.buffer',
                                         'django.contrib.gis.geos.GEOSGeometry.buffer_with_style': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.buffer_with_style',
                                         'django.contrib.gis.geos.GEOSGeometry.clone': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.clone',
                                         'django.contrib.gis.geos.GEOSGeometry.contains': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.contains',
                                         'django.contrib.gis.geos.GEOSGeometry.covers': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.covers',
                                         'django.contrib.gis.geos.GEOSGeometry.crosses': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.crosses',
                                         'django.contrib.gis.geos.GEOSGeometry.difference': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.difference',
                                         'django.contrib.gis.geos.GEOSGeometry.disjoint': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.disjoint',
                                         'django.contrib.gis.geos.GEOSGeometry.distance': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.distance',
                                         'django.contrib.gis.geos.GEOSGeometry.equals': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.equals',
                                         'django.contrib.gis.geos.GEOSGeometry.equals_exact': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.equals_exact',
                                         'django.contrib.gis.geos.GEOSGeometry.from_gml': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.from_gml',
                                         'django.contrib.gis.geos.GEOSGeometry.interpolate': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.interpolate',
                                         'django.contrib.gis.geos.GEOSGeometry.interpolate_normalized': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.interpolate_normalized',
                                         'django.contrib.gis.geos.GEOSGeometry.intersection': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.intersection',
                                         'django.contrib.gis.geos.GEOSGeometry.intersects': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.intersects',
                                         'django.contrib.gis.geos.GEOSGeometry.make_valid': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.make_valid',
                                         'django.contrib.gis.geos.GEOSGeometry.normalize': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.normalize',
                                         'django.contrib.gis.geos.GEOSGeometry.overlaps': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.overlaps',
                                         'django.contrib.gis.geos.GEOSGeometry.project': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.project',
                                         'django.contrib.gis.geos.GEOSGeometry.project_normalized': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.project_normalized',
                                         'django.contrib.gis.geos.GEOSGeometry.relate': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.relate',
                                         'django.contrib.gis.geos.GEOSGeometry.relate_pattern': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.relate_pattern',
                                         'django.contrib.gis.geos.GEOSGeometry.simplify': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.simplify',
                                         'django.contrib.gis.geos.GEOSGeometry.sym_difference': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.sym_difference',
                                         'django.contrib.gis.geos.GEOSGeometry.touches': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.touches',
                                         'django.contrib.gis.geos.GEOSGeometry.transform': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.transform',
                                         'django.contrib.gis.geos.GEOSGeometry.union': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.union',
                                         'django.contrib.gis.geos.GEOSGeometry.within': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GEOSGeometry.within',
                                         'django.contrib.gis.geos.GeometryCollection': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.GeometryCollection',
                                         'django.contrib.gis.geos.LineString': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.LineString',
                                         'django.contrib.gis.geos.LinearRing': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.LinearRing',
                                         'django.contrib.gis.geos.MultiLineString': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.MultiLineString',
                                         'django.contrib.gis.geos.MultiPoint': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.MultiPoint',
                                         'django.contrib.gis.geos.MultiPolygon': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.MultiPolygon',
                                         'django.contrib.gis.geos.Point': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.Point',
                                         'django.contrib.gis.geos.Polygon': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.Polygon',
                                         'django.contrib.gis.geos.Polygon.from_bbox': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.Polygon.from_bbox',
                                         'django.contrib.gis.geos.PreparedGeometry': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.PreparedGeometry',
                                         'django.contrib.gis.geos.PreparedGeometry.contains': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.PreparedGeometry.contains',
                                         'django.contrib.gis.geos.PreparedGeometry.contains_properly': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.PreparedGeometry.contains_properly',
                                         'django.contrib.gis.geos.PreparedGeometry.covers': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.PreparedGeometry.covers',
                                         'django.contrib.gis.geos.PreparedGeometry.crosses': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.PreparedGeometry.crosses',
                                         'django.contrib.gis.geos.PreparedGeometry.disjoint': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.PreparedGeometry.disjoint',
                                         'django.contrib.gis.geos.PreparedGeometry.intersects': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.PreparedGeometry.intersects',
                                         'django.contrib.gis.geos.PreparedGeometry.overlaps': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.PreparedGeometry.overlaps',
                                         'django.contrib.gis.geos.PreparedGeometry.touches': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.PreparedGeometry.touches',
                                         'django.contrib.gis.geos.PreparedGeometry.within': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.PreparedGeometry.within',
                                         'django.contrib.gis.geos.WKBReader': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.WKBReader',
                                         'django.contrib.gis.geos.WKBWriter': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.WKBWriter',
                                         'django.contrib.gis.geos.WKBWriter.write': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.WKBWriter.write',
                                         'django.contrib.gis.geos.WKBWriter.write_hex': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.WKBWriter.write_hex',
                                         'django.contrib.gis.geos.WKTReader': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.WKTReader',
                                         'django.contrib.gis.geos.WKTWriter': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.WKTWriter',
                                         'django.contrib.gis.geos.WKTWriter.write': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.WKTWriter.write',
                                         'django.contrib.gis.geos.fromfile': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.fromfile',
                                         'django.contrib.gis.geos.fromstr': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/geos.html#django.contrib.gis.geos.fromstr'},
            'django.contrib.gis.measure': { 'django.contrib.gis.measure.A': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/measure.html#django.contrib.gis.measure.A',
                                            'django.contrib.gis.measure.Area': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/measure.html#django.contrib.gis.measure.Area',
                                            'django.contrib.gis.measure.Area.__getattr__': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/measure.html#django.contrib.gis.measure.Area.__getattr__',
                                            'django.contrib.gis.measure.Area.unit_attname': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/measure.html#django.contrib.gis.measure.Area.unit_attname',
                                            'django.contrib.gis.measure.D': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/measure.html#django.contrib.gis.measure.D',
                                            'django.contrib.gis.measure.Distance': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/measure.html#django.contrib.gis.measure.Distance',
                                            'django.contrib.gis.measure.Distance.__getattr__': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/measure.html#django.contrib.gis.measure.Distance.__getattr__',
                                            'django.contrib.gis.measure.Distance.unit_attname': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/measure.html#django.contrib.gis.measure.Distance.unit_attname'},
            'django.contrib.gis.serializers': { 'django.contrib.gis.serializers.geojson': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/serializers.html#module-django.contrib.gis.serializers.geojson'},
            'django.contrib.gis.utils': { 'django.contrib.gis.utils.LayerMapping': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/layermapping.html#django.contrib.gis.utils.LayerMapping',
                                          'django.contrib.gis.utils.LayerMapping.save': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/layermapping.html#django.contrib.gis.utils.LayerMapping.save',
                                          'django.contrib.gis.utils.layermapping': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/layermapping.html#module-django.contrib.gis.utils.layermapping',
                                          'django.contrib.gis.utils.mapping': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/ogrinspect.html#django.contrib.gis.utils.mapping',
                                          'django.contrib.gis.utils.ogrinspect': 'http://django.readthedocs.org/en/latest/ref/contrib/gis/ogrinspect.html#module-django.contrib.gis.utils.ogrinspect'},
            'django.contrib.messages': { 'django.contrib.messages.add_message': 'http://django.readthedocs.org/en/latest/ref/contrib/messages.html#django.contrib.messages.add_message',
                                         'django.contrib.messages.get_messages': 'http://django.readthedocs.org/en/latest/ref/contrib/messages.html#django.contrib.messages.get_messages',
                                         'django.contrib.messages.middleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.contrib.messages.middleware'},
            'django.contrib.messages.middleware': { 'django.contrib.messages.middleware.MessageMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.contrib.messages.middleware.MessageMiddleware'},
            'django.contrib.messages.storage.base': { 'django.contrib.messages.storage.base.BaseStorage': 'http://django.readthedocs.org/en/latest/ref/contrib/messages.html#django.contrib.messages.storage.base.BaseStorage',
                                                      'django.contrib.messages.storage.base.Message': 'http://django.readthedocs.org/en/latest/ref/contrib/messages.html#django.contrib.messages.storage.base.Message'},
            'django.contrib.messages.storage.cookie': { 'django.contrib.messages.storage.cookie.CookieStorage': 'http://django.readthedocs.org/en/latest/ref/contrib/messages.html#django.contrib.messages.storage.cookie.CookieStorage'},
            'django.contrib.messages.storage.fallback': { 'django.contrib.messages.storage.fallback.FallbackStorage': 'http://django.readthedocs.org/en/latest/ref/contrib/messages.html#django.contrib.messages.storage.fallback.FallbackStorage'},
            'django.contrib.messages.storage.session': { 'django.contrib.messages.storage.session.SessionStorage': 'http://django.readthedocs.org/en/latest/ref/contrib/messages.html#django.contrib.messages.storage.session.SessionStorage'},
            'django.contrib.messages.views': { 'django.contrib.messages.views.SuccessMessageMixin': 'http://django.readthedocs.org/en/latest/ref/contrib/messages.html#django.contrib.messages.views.SuccessMessageMixin',
                                               'django.contrib.messages.views.SuccessMessageMixin.get_success_message': 'http://django.readthedocs.org/en/latest/ref/contrib/messages.html#django.contrib.messages.views.SuccessMessageMixin.get_success_message'},
            'django.contrib.postgres': { 'django.contrib.postgres.aggregates': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#module-django.contrib.postgres.aggregates',
                                         'django.contrib.postgres.constraints': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/constraints.html#module-django.contrib.postgres.constraints',
                                         'django.contrib.postgres.expressions': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/expressions.html#module-django.contrib.postgres.expressions',
                                         'django.contrib.postgres.indexes': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/indexes.html#module-django.contrib.postgres.indexes',
                                         'django.contrib.postgres.validators': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/validators.html#module-django.contrib.postgres.validators'},
            'django.contrib.postgres.aggregates': { 'django.contrib.postgres.aggregates.ArrayAgg': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.ArrayAgg',
                                                    'django.contrib.postgres.aggregates.BitAnd': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.BitAnd',
                                                    'django.contrib.postgres.aggregates.BitOr': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.BitOr',
                                                    'django.contrib.postgres.aggregates.BitXor': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.BitXor',
                                                    'django.contrib.postgres.aggregates.BoolAnd': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.BoolAnd',
                                                    'django.contrib.postgres.aggregates.BoolOr': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.BoolOr',
                                                    'django.contrib.postgres.aggregates.Corr': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.Corr',
                                                    'django.contrib.postgres.aggregates.CovarPop': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.CovarPop',
                                                    'django.contrib.postgres.aggregates.JSONBAgg': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.JSONBAgg',
                                                    'django.contrib.postgres.aggregates.RegrAvgX': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.RegrAvgX',
                                                    'django.contrib.postgres.aggregates.RegrAvgY': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.RegrAvgY',
                                                    'django.contrib.postgres.aggregates.RegrCount': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.RegrCount',
                                                    'django.contrib.postgres.aggregates.RegrIntercept': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.RegrIntercept',
                                                    'django.contrib.postgres.aggregates.RegrR2': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.RegrR2',
                                                    'django.contrib.postgres.aggregates.RegrSXX': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.RegrSXX',
                                                    'django.contrib.postgres.aggregates.RegrSXY': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.RegrSXY',
                                                    'django.contrib.postgres.aggregates.RegrSYY': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.RegrSYY',
                                                    'django.contrib.postgres.aggregates.RegrSlope': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.RegrSlope',
                                                    'django.contrib.postgres.aggregates.StringAgg': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/aggregates.html#django.contrib.postgres.aggregates.StringAgg'},
            'django.contrib.postgres.constraints': { 'django.contrib.postgres.constraints.ExclusionConstraint': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/constraints.html#django.contrib.postgres.constraints.ExclusionConstraint'},
            'django.contrib.postgres.expressions': { 'django.contrib.postgres.expressions.ArraySubquery': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/expressions.html#django.contrib.postgres.expressions.ArraySubquery'},
            'django.contrib.postgres.fields': { 'django.contrib.postgres.fields.ArrayField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.ArrayField',
                                                'django.contrib.postgres.fields.BigIntegerRangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.BigIntegerRangeField',
                                                'django.contrib.postgres.fields.CICharField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.CICharField',
                                                'django.contrib.postgres.fields.CIEmailField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.CIEmailField',
                                                'django.contrib.postgres.fields.CIText': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.CIText',
                                                'django.contrib.postgres.fields.CITextField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.CITextField',
                                                'django.contrib.postgres.fields.DateRangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.DateRangeField',
                                                'django.contrib.postgres.fields.DateTimeRangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.DateTimeRangeField',
                                                'django.contrib.postgres.fields.DecimalRangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.DecimalRangeField',
                                                'django.contrib.postgres.fields.HStoreField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.HStoreField',
                                                'django.contrib.postgres.fields.IntegerRangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.IntegerRangeField',
                                                'django.contrib.postgres.fields.RangeBoundary': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.RangeBoundary',
                                                'django.contrib.postgres.fields.RangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.RangeField',
                                                'django.contrib.postgres.fields.RangeOperators': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.RangeOperators'},
            'django.contrib.postgres.fields.django.contrib.postgres.forms': { 'django.contrib.postgres.fields.django.contrib.postgres.forms.BaseRangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/fields.html#django.contrib.postgres.fields.django.contrib.postgres.forms.BaseRangeField'},
            'django.contrib.postgres.forms': { 'django.contrib.postgres.forms.DateRangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/forms.html#django.contrib.postgres.forms.DateRangeField',
                                               'django.contrib.postgres.forms.DateTimeRangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/forms.html#django.contrib.postgres.forms.DateTimeRangeField',
                                               'django.contrib.postgres.forms.DecimalRangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/forms.html#django.contrib.postgres.forms.DecimalRangeField',
                                               'django.contrib.postgres.forms.HStoreField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/forms.html#django.contrib.postgres.forms.HStoreField',
                                               'django.contrib.postgres.forms.IntegerRangeField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/forms.html#django.contrib.postgres.forms.IntegerRangeField',
                                               'django.contrib.postgres.forms.RangeWidget': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/forms.html#django.contrib.postgres.forms.RangeWidget',
                                               'django.contrib.postgres.forms.RangeWidget.decompress': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/forms.html#django.contrib.postgres.forms.RangeWidget.decompress',
                                               'django.contrib.postgres.forms.SimpleArrayField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/forms.html#django.contrib.postgres.forms.SimpleArrayField',
                                               'django.contrib.postgres.forms.SplitArrayField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/forms.html#django.contrib.postgres.forms.SplitArrayField'},
            'django.contrib.postgres.functions': { 'django.contrib.postgres.functions.RandomUUID': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/functions.html#django.contrib.postgres.functions.RandomUUID',
                                                   'django.contrib.postgres.functions.TransactionNow': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/functions.html#django.contrib.postgres.functions.TransactionNow'},
            'django.contrib.postgres.indexes': { 'django.contrib.postgres.indexes.BTreeIndex': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/indexes.html#django.contrib.postgres.indexes.BTreeIndex',
                                                 'django.contrib.postgres.indexes.BloomIndex': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/indexes.html#django.contrib.postgres.indexes.BloomIndex',
                                                 'django.contrib.postgres.indexes.BrinIndex': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/indexes.html#django.contrib.postgres.indexes.BrinIndex',
                                                 'django.contrib.postgres.indexes.GinIndex': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/indexes.html#django.contrib.postgres.indexes.GinIndex',
                                                 'django.contrib.postgres.indexes.GistIndex': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/indexes.html#django.contrib.postgres.indexes.GistIndex',
                                                 'django.contrib.postgres.indexes.HashIndex': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/indexes.html#django.contrib.postgres.indexes.HashIndex',
                                                 'django.contrib.postgres.indexes.OpClass': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/indexes.html#django.contrib.postgres.indexes.OpClass',
                                                 'django.contrib.postgres.indexes.SpGistIndex': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/indexes.html#django.contrib.postgres.indexes.SpGistIndex'},
            'django.contrib.postgres.operations': { 'django.contrib.postgres.operations.AddConstraintNotValid': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.AddConstraintNotValid',
                                                    'django.contrib.postgres.operations.AddIndexConcurrently': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.AddIndexConcurrently',
                                                    'django.contrib.postgres.operations.BloomExtension': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.BloomExtension',
                                                    'django.contrib.postgres.operations.BtreeGinExtension': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.BtreeGinExtension',
                                                    'django.contrib.postgres.operations.BtreeGistExtension': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.BtreeGistExtension',
                                                    'django.contrib.postgres.operations.CITextExtension': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.CITextExtension',
                                                    'django.contrib.postgres.operations.CreateCollation': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.CreateCollation',
                                                    'django.contrib.postgres.operations.CreateExtension': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.CreateExtension',
                                                    'django.contrib.postgres.operations.CryptoExtension': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.CryptoExtension',
                                                    'django.contrib.postgres.operations.HStoreExtension': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.HStoreExtension',
                                                    'django.contrib.postgres.operations.RemoveCollation': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.RemoveCollation',
                                                    'django.contrib.postgres.operations.RemoveIndexConcurrently': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.RemoveIndexConcurrently',
                                                    'django.contrib.postgres.operations.TrigramExtension': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.TrigramExtension',
                                                    'django.contrib.postgres.operations.UnaccentExtension': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.UnaccentExtension',
                                                    'django.contrib.postgres.operations.ValidateConstraint': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/operations.html#django.contrib.postgres.operations.ValidateConstraint'},
            'django.contrib.postgres.search': { 'django.contrib.postgres.search.SearchHeadline': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.SearchHeadline',
                                                'django.contrib.postgres.search.SearchQuery': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.SearchQuery',
                                                'django.contrib.postgres.search.SearchRank': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.SearchRank',
                                                'django.contrib.postgres.search.SearchVector': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.SearchVector',
                                                'django.contrib.postgres.search.SearchVectorField': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.SearchVectorField',
                                                'django.contrib.postgres.search.TrigramDistance': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.TrigramDistance',
                                                'django.contrib.postgres.search.TrigramSimilarity': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.TrigramSimilarity',
                                                'django.contrib.postgres.search.TrigramStrictWordDistance': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.TrigramStrictWordDistance',
                                                'django.contrib.postgres.search.TrigramStrictWordSimilarity': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.TrigramStrictWordSimilarity',
                                                'django.contrib.postgres.search.TrigramWordDistance': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.TrigramWordDistance',
                                                'django.contrib.postgres.search.TrigramWordSimilarity': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/search.html#django.contrib.postgres.search.TrigramWordSimilarity'},
            'django.contrib.postgres.validators': { 'django.contrib.postgres.validators.KeysValidator': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/validators.html#django.contrib.postgres.validators.KeysValidator',
                                                    'django.contrib.postgres.validators.RangeMaxValueValidator': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/validators.html#django.contrib.postgres.validators.RangeMaxValueValidator',
                                                    'django.contrib.postgres.validators.RangeMinValueValidator': 'http://django.readthedocs.org/en/latest/ref/contrib/postgres/validators.html#django.contrib.postgres.validators.RangeMinValueValidator'},
            'django.contrib.redirects.middleware': { 'django.contrib.redirects.middleware.RedirectFallbackMiddleware': 'http://django.readthedocs.org/en/latest/ref/contrib/redirects.html#django.contrib.redirects.middleware.RedirectFallbackMiddleware'},
            'django.contrib.redirects.models': { 'django.contrib.redirects.models.Redirect': 'http://django.readthedocs.org/en/latest/ref/contrib/redirects.html#django.contrib.redirects.models.Redirect'},
            'django.contrib.sessions': { 'django.contrib.sessions.middleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.contrib.sessions.middleware'},
            'django.contrib.sessions.backends.base': { 'django.contrib.sessions.backends.base.SessionBase': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase',
                                                       'django.contrib.sessions.backends.base.SessionBase.__contains__': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.__contains__',
                                                       'django.contrib.sessions.backends.base.SessionBase.__delitem__': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.__delitem__',
                                                       'django.contrib.sessions.backends.base.SessionBase.__getitem__': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.__getitem__',
                                                       'django.contrib.sessions.backends.base.SessionBase.__setitem__': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.__setitem__',
                                                       'django.contrib.sessions.backends.base.SessionBase.clear': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.clear',
                                                       'django.contrib.sessions.backends.base.SessionBase.clear_expired': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.clear_expired',
                                                       'django.contrib.sessions.backends.base.SessionBase.cycle_key': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.cycle_key',
                                                       'django.contrib.sessions.backends.base.SessionBase.delete_test_cookie': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.delete_test_cookie',
                                                       'django.contrib.sessions.backends.base.SessionBase.flush': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.flush',
                                                       'django.contrib.sessions.backends.base.SessionBase.get': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.get',
                                                       'django.contrib.sessions.backends.base.SessionBase.get_expire_at_browser_close': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.get_expire_at_browser_close',
                                                       'django.contrib.sessions.backends.base.SessionBase.get_expiry_age': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.get_expiry_age',
                                                       'django.contrib.sessions.backends.base.SessionBase.get_expiry_date': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.get_expiry_date',
                                                       'django.contrib.sessions.backends.base.SessionBase.get_session_cookie_age': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.get_session_cookie_age',
                                                       'django.contrib.sessions.backends.base.SessionBase.items': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.items',
                                                       'django.contrib.sessions.backends.base.SessionBase.keys': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.keys',
                                                       'django.contrib.sessions.backends.base.SessionBase.pop': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.pop',
                                                       'django.contrib.sessions.backends.base.SessionBase.set_expiry': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.set_expiry',
                                                       'django.contrib.sessions.backends.base.SessionBase.set_test_cookie': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.set_test_cookie',
                                                       'django.contrib.sessions.backends.base.SessionBase.setdefault': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.setdefault',
                                                       'django.contrib.sessions.backends.base.SessionBase.test_cookie_worked': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.base.SessionBase.test_cookie_worked'},
            'django.contrib.sessions.backends.cached_db': { 'django.contrib.sessions.backends.cached_db.SessionStore': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.cached_db.SessionStore'},
            'django.contrib.sessions.backends.db': { 'django.contrib.sessions.backends.db.SessionStore': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.db.SessionStore',
                                                     'django.contrib.sessions.backends.db.SessionStore.create_model_instance': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.db.SessionStore.create_model_instance',
                                                     'django.contrib.sessions.backends.db.SessionStore.get_model_class': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.backends.db.SessionStore.get_model_class'},
            'django.contrib.sessions.base_session': { 'django.contrib.sessions.base_session.AbstractBaseSession': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.base_session.AbstractBaseSession',
                                                      'django.contrib.sessions.base_session.AbstractBaseSession.get_decoded': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.base_session.AbstractBaseSession.get_decoded',
                                                      'django.contrib.sessions.base_session.AbstractBaseSession.get_session_store_class': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.base_session.AbstractBaseSession.get_session_store_class',
                                                      'django.contrib.sessions.base_session.BaseSessionManager': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.base_session.BaseSessionManager',
                                                      'django.contrib.sessions.base_session.BaseSessionManager.encode': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.base_session.BaseSessionManager.encode',
                                                      'django.contrib.sessions.base_session.BaseSessionManager.save': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.base_session.BaseSessionManager.save'},
            'django.contrib.sessions.middleware': { 'django.contrib.sessions.middleware.SessionMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.contrib.sessions.middleware.SessionMiddleware'},
            'django.contrib.sessions.serializers': { 'django.contrib.sessions.serializers.JSONSerializer': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.serializers.JSONSerializer',
                                                     'django.contrib.sessions.serializers.PickleSerializer': 'http://django.readthedocs.org/en/latest/topics/http/sessions.html#django.contrib.sessions.serializers.PickleSerializer'},
            'django.contrib.sitemaps': { 'django.contrib.sitemaps.GenericSitemap': 'http://django.readthedocs.org/en/latest/ref/contrib/sitemaps.html#django.contrib.sitemaps.GenericSitemap',
                                         'django.contrib.sitemaps.Sitemap': 'http://django.readthedocs.org/en/latest/ref/contrib/sitemaps.html#django.contrib.sitemaps.Sitemap',
                                         'django.contrib.sitemaps.Sitemap.get_latest_lastmod': 'http://django.readthedocs.org/en/latest/ref/contrib/sitemaps.html#django.contrib.sitemaps.Sitemap.get_latest_lastmod',
                                         'django.contrib.sitemaps.ping_google': 'http://django.readthedocs.org/en/latest/ref/contrib/sitemaps.html#django.contrib.sitemaps.ping_google'},
            'django.contrib.sitemaps.views': { 'django.contrib.sitemaps.views.index': 'http://django.readthedocs.org/en/latest/ref/contrib/sitemaps.html#django.contrib.sitemaps.views.index',
                                               'django.contrib.sitemaps.views.sitemap': 'http://django.readthedocs.org/en/latest/ref/contrib/sitemaps.html#django.contrib.sitemaps.views.sitemap'},
            'django.contrib.sites': { 'django.contrib.sites.middleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.contrib.sites.middleware'},
            'django.contrib.sites.managers': { 'django.contrib.sites.managers.CurrentSiteManager': 'http://django.readthedocs.org/en/latest/ref/contrib/sites.html#django.contrib.sites.managers.CurrentSiteManager'},
            'django.contrib.sites.middleware': { 'django.contrib.sites.middleware.CurrentSiteMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.contrib.sites.middleware.CurrentSiteMiddleware'},
            'django.contrib.sites.models': { 'django.contrib.sites.models.Site': 'http://django.readthedocs.org/en/latest/ref/contrib/sites.html#django.contrib.sites.models.Site'},
            'django.contrib.sites.requests': { 'django.contrib.sites.requests.RequestSite': 'http://django.readthedocs.org/en/latest/ref/contrib/sites.html#django.contrib.sites.requests.RequestSite',
                                               'django.contrib.sites.requests.RequestSite.__init__': 'http://django.readthedocs.org/en/latest/ref/contrib/sites.html#django.contrib.sites.requests.RequestSite.__init__'},
            'django.contrib.sites.shortcuts': { 'django.contrib.sites.shortcuts.get_current_site': 'http://django.readthedocs.org/en/latest/ref/contrib/sites.html#django.contrib.sites.shortcuts.get_current_site'},
            'django.contrib.staticfiles.storage': { 'django.contrib.staticfiles.storage.ManifestFilesMixin': 'http://django.readthedocs.org/en/latest/ref/contrib/staticfiles.html#django.contrib.staticfiles.storage.ManifestFilesMixin',
                                                    'django.contrib.staticfiles.storage.ManifestStaticFilesStorage': 'http://django.readthedocs.org/en/latest/ref/contrib/staticfiles.html#django.contrib.staticfiles.storage.ManifestStaticFilesStorage',
                                                    'django.contrib.staticfiles.storage.ManifestStaticFilesStorage.file_hash': 'http://django.readthedocs.org/en/latest/ref/contrib/staticfiles.html#django.contrib.staticfiles.storage.ManifestStaticFilesStorage.file_hash',
                                                    'django.contrib.staticfiles.storage.StaticFilesStorage': 'http://django.readthedocs.org/en/latest/ref/contrib/staticfiles.html#django.contrib.staticfiles.storage.StaticFilesStorage',
                                                    'django.contrib.staticfiles.storage.StaticFilesStorage.post_process': 'http://django.readthedocs.org/en/latest/ref/contrib/staticfiles.html#django.contrib.staticfiles.storage.StaticFilesStorage.post_process'},
            'django.contrib.staticfiles.testing': { 'django.contrib.staticfiles.testing.StaticLiveServerTestCase': 'http://django.readthedocs.org/en/latest/ref/contrib/staticfiles.html#django.contrib.staticfiles.testing.StaticLiveServerTestCase'},
            'django.contrib.staticfiles.urls': { 'django.contrib.staticfiles.urls.staticfiles_urlpatterns': 'http://django.readthedocs.org/en/latest/ref/contrib/staticfiles.html#django.contrib.staticfiles.urls.staticfiles_urlpatterns'},
            'django.contrib.staticfiles.views': { 'django.contrib.staticfiles.views.serve': 'http://django.readthedocs.org/en/latest/ref/contrib/staticfiles.html#django.contrib.staticfiles.views.serve'},
            'django.contrib.syndication': { 'django.contrib.syndication.Feed.get_context_data': 'http://django.readthedocs.org/en/latest/ref/contrib/syndication.html#django.contrib.syndication.Feed.get_context_data'},
            'django.contrib.syndication.views': { 'django.contrib.syndication.views.Feed': 'http://django.readthedocs.org/en/latest/ref/contrib/syndication.html#django.contrib.syndication.views.Feed'},
            'django.core': { 'django.core.checks': 'http://django.readthedocs.org/en/latest/topics/checks.html#module-django.core.checks',
                             'django.core.exceptions': 'http://django.readthedocs.org/en/latest/ref/exceptions.html#module-django.core.exceptions',
                             'django.core.files': 'http://django.readthedocs.org/en/latest/ref/files/index.html#module-django.core.files',
                             'django.core.mail': 'http://django.readthedocs.org/en/latest/topics/email.html#module-django.core.mail',
                             'django.core.management': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#module-django.core.management',
                             'django.core.paginator': 'http://django.readthedocs.org/en/latest/ref/paginator.html#module-django.core.paginator',
                             'django.core.signals': 'http://django.readthedocs.org/en/latest/ref/signals.html#module-django.core.signals',
                             'django.core.signing': 'http://django.readthedocs.org/en/latest/topics/signing.html#module-django.core.signing',
                             'django.core.validators': 'http://django.readthedocs.org/en/latest/ref/validators.html#module-django.core.validators'},
            'django.core.cache.utils': { 'django.core.cache.utils.make_template_fragment_key': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.cache.utils.make_template_fragment_key'},
            'django.core.caches': { 'django.core.caches.cache.add': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.add',
                                    'django.core.caches.cache.clear': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.clear',
                                    'django.core.caches.cache.close': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.close',
                                    'django.core.caches.cache.decr': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.decr',
                                    'django.core.caches.cache.delete': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.delete',
                                    'django.core.caches.cache.delete_many': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.delete_many',
                                    'django.core.caches.cache.get': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.get',
                                    'django.core.caches.cache.get_many': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.get_many',
                                    'django.core.caches.cache.get_or_set': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.get_or_set',
                                    'django.core.caches.cache.incr': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.incr',
                                    'django.core.caches.cache.set': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.set',
                                    'django.core.caches.cache.set_many': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.set_many',
                                    'django.core.caches.cache.touch': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.core.caches.cache.touch'},
            'django.core.checks': { 'django.core.checks.CheckMessage': 'http://django.readthedocs.org/en/latest/ref/checks.html#django.core.checks.CheckMessage',
                                    'django.core.checks.Critical': 'http://django.readthedocs.org/en/latest/ref/checks.html#django.core.checks.Critical',
                                    'django.core.checks.Debug': 'http://django.readthedocs.org/en/latest/ref/checks.html#django.core.checks.Debug',
                                    'django.core.checks.Error': 'http://django.readthedocs.org/en/latest/ref/checks.html#django.core.checks.Error',
                                    'django.core.checks.Info': 'http://django.readthedocs.org/en/latest/ref/checks.html#django.core.checks.Info',
                                    'django.core.checks.Warning': 'http://django.readthedocs.org/en/latest/ref/checks.html#django.core.checks.Warning',
                                    'django.core.checks.register': 'http://django.readthedocs.org/en/latest/topics/checks.html#django.core.checks.register'},
            'django.core.files': { 'django.core.files.File': 'http://django.readthedocs.org/en/latest/ref/files/file.html#django.core.files.File',
                                   'django.core.files.File.__iter__': 'http://django.readthedocs.org/en/latest/ref/files/file.html#django.core.files.File.__iter__',
                                   'django.core.files.File.chunks': 'http://django.readthedocs.org/en/latest/ref/files/file.html#django.core.files.File.chunks',
                                   'django.core.files.File.close': 'http://django.readthedocs.org/en/latest/ref/files/file.html#django.core.files.File.close',
                                   'django.core.files.File.delete': 'http://django.readthedocs.org/en/latest/ref/files/file.html#django.core.files.File.delete',
                                   'django.core.files.File.multiple_chunks': 'http://django.readthedocs.org/en/latest/ref/files/file.html#django.core.files.File.multiple_chunks',
                                   'django.core.files.File.open': 'http://django.readthedocs.org/en/latest/ref/files/file.html#django.core.files.File.open',
                                   'django.core.files.File.save': 'http://django.readthedocs.org/en/latest/ref/files/file.html#django.core.files.File.save',
                                   'django.core.files.storage': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#module-django.core.files.storage',
                                   'django.core.files.storage._open': 'http://django.readthedocs.org/en/latest/howto/custom-file-storage.html#django.core.files.storage._open',
                                   'django.core.files.storage._save': 'http://django.readthedocs.org/en/latest/howto/custom-file-storage.html#django.core.files.storage._save',
                                   'django.core.files.storage.get_alternative_name': 'http://django.readthedocs.org/en/latest/howto/custom-file-storage.html#django.core.files.storage.get_alternative_name',
                                   'django.core.files.storage.get_available_name': 'http://django.readthedocs.org/en/latest/howto/custom-file-storage.html#django.core.files.storage.get_available_name',
                                   'django.core.files.storage.get_valid_name': 'http://django.readthedocs.org/en/latest/howto/custom-file-storage.html#django.core.files.storage.get_valid_name',
                                   'django.core.files.uploadedfile': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#module-django.core.files.uploadedfile',
                                   'django.core.files.uploadhandler': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#module-django.core.files.uploadhandler'},
            'django.core.files.base': { 'django.core.files.base.ContentFile': 'http://django.readthedocs.org/en/latest/ref/files/file.html#django.core.files.base.ContentFile'},
            'django.core.files.images': { 'django.core.files.images.ImageFile': 'http://django.readthedocs.org/en/latest/ref/files/file.html#django.core.files.images.ImageFile'},
            'django.core.files.storage': { 'django.core.files.storage.DefaultStorage': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.DefaultStorage',
                                           'django.core.files.storage.FileSystemStorage': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.FileSystemStorage',
                                           'django.core.files.storage.FileSystemStorage.get_created_time': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.FileSystemStorage.get_created_time',
                                           'django.core.files.storage.Storage': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage',
                                           'django.core.files.storage.Storage.delete': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.delete',
                                           'django.core.files.storage.Storage.exists': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.exists',
                                           'django.core.files.storage.Storage.generate_filename': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.generate_filename',
                                           'django.core.files.storage.Storage.get_accessed_time': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.get_accessed_time',
                                           'django.core.files.storage.Storage.get_alternative_name': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.get_alternative_name',
                                           'django.core.files.storage.Storage.get_available_name': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.get_available_name',
                                           'django.core.files.storage.Storage.get_created_time': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.get_created_time',
                                           'django.core.files.storage.Storage.get_modified_time': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.get_modified_time',
                                           'django.core.files.storage.Storage.get_valid_name': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.get_valid_name',
                                           'django.core.files.storage.Storage.listdir': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.listdir',
                                           'django.core.files.storage.Storage.open': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.open',
                                           'django.core.files.storage.Storage.path': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.path',
                                           'django.core.files.storage.Storage.save': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.save',
                                           'django.core.files.storage.Storage.size': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.size',
                                           'django.core.files.storage.Storage.url': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.Storage.url',
                                           'django.core.files.storage.get_storage_class': 'http://django.readthedocs.org/en/latest/ref/files/storage.html#django.core.files.storage.get_storage_class'},
            'django.core.files.uploadedfile': { 'django.core.files.uploadedfile.InMemoryUploadedFile': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadedfile.InMemoryUploadedFile',
                                                'django.core.files.uploadedfile.TemporaryUploadedFile': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadedfile.TemporaryUploadedFile',
                                                'django.core.files.uploadedfile.TemporaryUploadedFile.temporary_file_path': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadedfile.TemporaryUploadedFile.temporary_file_path',
                                                'django.core.files.uploadedfile.UploadedFile': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadedfile.UploadedFile',
                                                'django.core.files.uploadedfile.UploadedFile.chunks': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadedfile.UploadedFile.chunks',
                                                'django.core.files.uploadedfile.UploadedFile.multiple_chunks': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadedfile.UploadedFile.multiple_chunks',
                                                'django.core.files.uploadedfile.UploadedFile.read': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadedfile.UploadedFile.read'},
            'django.core.files.uploadhandler': { 'django.core.files.uploadhandler.FileUploadHandler': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadhandler.FileUploadHandler',
                                                 'django.core.files.uploadhandler.FileUploadHandler.file_complete': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadhandler.FileUploadHandler.file_complete',
                                                 'django.core.files.uploadhandler.FileUploadHandler.handle_raw_input': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadhandler.FileUploadHandler.handle_raw_input',
                                                 'django.core.files.uploadhandler.FileUploadHandler.new_file': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadhandler.FileUploadHandler.new_file',
                                                 'django.core.files.uploadhandler.FileUploadHandler.receive_data_chunk': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadhandler.FileUploadHandler.receive_data_chunk',
                                                 'django.core.files.uploadhandler.FileUploadHandler.upload_complete': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadhandler.FileUploadHandler.upload_complete',
                                                 'django.core.files.uploadhandler.FileUploadHandler.upload_interrupted': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadhandler.FileUploadHandler.upload_interrupted',
                                                 'django.core.files.uploadhandler.MemoryFileUploadHandler': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadhandler.MemoryFileUploadHandler',
                                                 'django.core.files.uploadhandler.TemporaryFileUploadHandler': 'http://django.readthedocs.org/en/latest/ref/files/uploads.html#django.core.files.uploadhandler.TemporaryFileUploadHandler'},
            'django.core.mail': { 'django.core.mail.EmailMessage': 'http://django.readthedocs.org/en/latest/topics/email.html#django.core.mail.EmailMessage',
                                  'django.core.mail.get_connection': 'http://django.readthedocs.org/en/latest/topics/email.html#django.core.mail.get_connection',
                                  'django.core.mail.mail_admins': 'http://django.readthedocs.org/en/latest/topics/email.html#django.core.mail.mail_admins',
                                  'django.core.mail.mail_managers': 'http://django.readthedocs.org/en/latest/topics/email.html#django.core.mail.mail_managers',
                                  'django.core.mail.send_mail': 'http://django.readthedocs.org/en/latest/topics/email.html#django.core.mail.send_mail',
                                  'django.core.mail.send_mass_mail': 'http://django.readthedocs.org/en/latest/topics/email.html#django.core.mail.send_mass_mail'},
            'django.core.mail.backends.smtp': { 'django.core.mail.backends.smtp.EmailBackend': 'http://django.readthedocs.org/en/latest/topics/email.html#django.core.mail.backends.smtp.EmailBackend'},
            'django.core.management': { 'django.core.management.AppCommand': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.AppCommand',
                                        'django.core.management.AppCommand.handle_app_config': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.AppCommand.handle_app_config',
                                        'django.core.management.BaseCommand': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.BaseCommand',
                                        'django.core.management.BaseCommand.add_arguments': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.BaseCommand.add_arguments',
                                        'django.core.management.BaseCommand.check': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.BaseCommand.check',
                                        'django.core.management.BaseCommand.create_parser': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.BaseCommand.create_parser',
                                        'django.core.management.BaseCommand.execute': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.BaseCommand.execute',
                                        'django.core.management.BaseCommand.get_version': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.BaseCommand.get_version',
                                        'django.core.management.BaseCommand.handle': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.BaseCommand.handle',
                                        'django.core.management.LabelCommand': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.LabelCommand',
                                        'django.core.management.LabelCommand.handle_label': 'http://django.readthedocs.org/en/latest/howto/custom-management-commands.html#django.core.management.LabelCommand.handle_label',
                                        'django.core.management.call_command': 'http://django.readthedocs.org/en/latest/ref/django-admin.html#django.core.management.call_command'},
            'django.core.paginator': { 'django.core.paginator.Page': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Page',
                                       'django.core.paginator.Page.end_index': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Page.end_index',
                                       'django.core.paginator.Page.has_next': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Page.has_next',
                                       'django.core.paginator.Page.has_other_pages': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Page.has_other_pages',
                                       'django.core.paginator.Page.has_previous': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Page.has_previous',
                                       'django.core.paginator.Page.next_page_number': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Page.next_page_number',
                                       'django.core.paginator.Page.previous_page_number': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Page.previous_page_number',
                                       'django.core.paginator.Page.start_index': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Page.start_index',
                                       'django.core.paginator.Paginator': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Paginator',
                                       'django.core.paginator.Paginator.get_elided_page_range': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Paginator.get_elided_page_range',
                                       'django.core.paginator.Paginator.get_page': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Paginator.get_page',
                                       'django.core.paginator.Paginator.page': 'http://django.readthedocs.org/en/latest/ref/paginator.html#django.core.paginator.Paginator.page'},
            'django.core.serializers': { 'django.core.serializers.get_serializer': 'http://django.readthedocs.org/en/latest/topics/serialization.html#django.core.serializers.get_serializer'},
            'django.core.serializers.json': { 'django.core.serializers.json.DjangoJSONEncoder': 'http://django.readthedocs.org/en/latest/topics/serialization.html#django.core.serializers.json.DjangoJSONEncoder'},
            'django.core.signing': { 'django.core.signing.Signer': 'http://django.readthedocs.org/en/latest/topics/signing.html#django.core.signing.Signer',
                                     'django.core.signing.TimestampSigner': 'http://django.readthedocs.org/en/latest/topics/signing.html#django.core.signing.TimestampSigner',
                                     'django.core.signing.TimestampSigner.sign': 'http://django.readthedocs.org/en/latest/topics/signing.html#django.core.signing.TimestampSigner.sign',
                                     'django.core.signing.TimestampSigner.sign_object': 'http://django.readthedocs.org/en/latest/topics/signing.html#django.core.signing.TimestampSigner.sign_object',
                                     'django.core.signing.TimestampSigner.unsign': 'http://django.readthedocs.org/en/latest/topics/signing.html#django.core.signing.TimestampSigner.unsign',
                                     'django.core.signing.TimestampSigner.unsign_object': 'http://django.readthedocs.org/en/latest/topics/signing.html#django.core.signing.TimestampSigner.unsign_object',
                                     'django.core.signing.dumps': 'http://django.readthedocs.org/en/latest/topics/signing.html#django.core.signing.dumps',
                                     'django.core.signing.loads': 'http://django.readthedocs.org/en/latest/topics/signing.html#django.core.signing.loads'},
            'django.core.validators': { 'django.core.validators.DecimalValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.DecimalValidator',
                                        'django.core.validators.EmailValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.EmailValidator',
                                        'django.core.validators.FileExtensionValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.FileExtensionValidator',
                                        'django.core.validators.MaxLengthValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.MaxLengthValidator',
                                        'django.core.validators.MaxValueValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.MaxValueValidator',
                                        'django.core.validators.MinLengthValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.MinLengthValidator',
                                        'django.core.validators.MinValueValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.MinValueValidator',
                                        'django.core.validators.ProhibitNullCharactersValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.ProhibitNullCharactersValidator',
                                        'django.core.validators.RegexValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.RegexValidator',
                                        'django.core.validators.StepValueValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.StepValueValidator',
                                        'django.core.validators.URLValidator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.URLValidator',
                                        'django.core.validators.int_list_validator': 'http://django.readthedocs.org/en/latest/ref/validators.html#django.core.validators.int_list_validator'},
            'django.db': { 'django.db.backends': 'http://django.readthedocs.org/en/latest/ref/signals.html#module-django.db.backends',
                           'django.db.migrations': 'http://django.readthedocs.org/en/latest/topics/migrations.html#module-django.db.migrations',
                           'django.db.models': 'http://django.readthedocs.org/en/latest/topics/db/models.html#module-django.db.models',
                           'django.db.models.as_sql': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.as_sql',
                           'django.db.models.as_vendorname': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.as_vendorname',
                           'django.db.models.from_queryset': 'http://django.readthedocs.org/en/latest/topics/db/managers.html#django.db.models.from_queryset',
                           'django.db.models.get_lookup': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.get_lookup',
                           'django.db.models.get_transform': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.get_transform',
                           'django.db.transaction': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#module-django.db.transaction'},
            'django.db.backends.base': { 'django.db.backends.base.DatabaseWrapper.execute_wrapper': 'http://django.readthedocs.org/en/latest/topics/db/instrumentation.html#django.db.backends.base.DatabaseWrapper.execute_wrapper',
                                         'django.db.backends.base.schema': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#module-django.db.backends.base.schema'},
            'django.db.backends.base.schema': { 'django.db.backends.base.schema.BaseDatabaseSchemaEditor': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.add_constraint': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.add_constraint',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.add_field': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.add_field',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.add_index': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.add_index',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.alter_db_table': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.alter_db_table',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.alter_db_tablespace': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.alter_db_tablespace',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.alter_field': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.alter_field',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.alter_index_together': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.alter_index_together',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.alter_unique_together': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.alter_unique_together',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.create_model': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.create_model',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.delete_model': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.delete_model',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.execute': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.execute',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.remove_constraint': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.remove_constraint',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.remove_field': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.remove_field',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.remove_index': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.remove_index',
                                                'django.db.backends.base.schema.BaseDatabaseSchemaEditor.rename_index': 'http://django.readthedocs.org/en/latest/ref/schema-editor.html#django.db.backends.base.schema.BaseDatabaseSchemaEditor.rename_index'},
            'django.db.connection.creation': { 'django.db.connection.creation.create_test_db': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.db.connection.creation.create_test_db',
                                               'django.db.connection.creation.destroy_test_db': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.db.connection.creation.destroy_test_db'},
            'django.db.migrations': { 'django.db.migrations.operations': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#module-django.db.migrations.operations'},
            'django.db.migrations.operations': { 'django.db.migrations.operations.AddConstraint': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.AddConstraint',
                                                 'django.db.migrations.operations.AddField': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.AddField',
                                                 'django.db.migrations.operations.AddIndex': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.AddIndex',
                                                 'django.db.migrations.operations.AlterField': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.AlterField',
                                                 'django.db.migrations.operations.AlterIndexTogether': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.AlterIndexTogether',
                                                 'django.db.migrations.operations.AlterModelManagers': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.AlterModelManagers',
                                                 'django.db.migrations.operations.AlterModelOptions': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.AlterModelOptions',
                                                 'django.db.migrations.operations.AlterModelTable': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.AlterModelTable',
                                                 'django.db.migrations.operations.AlterOrderWithRespectTo': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.AlterOrderWithRespectTo',
                                                 'django.db.migrations.operations.AlterUniqueTogether': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.AlterUniqueTogether',
                                                 'django.db.migrations.operations.CreateModel': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.CreateModel',
                                                 'django.db.migrations.operations.DeleteModel': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.DeleteModel',
                                                 'django.db.migrations.operations.RemoveConstraint': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.RemoveConstraint',
                                                 'django.db.migrations.operations.RemoveField': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.RemoveField',
                                                 'django.db.migrations.operations.RemoveIndex': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.RemoveIndex',
                                                 'django.db.migrations.operations.RenameField': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.RenameField',
                                                 'django.db.migrations.operations.RenameIndex': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.RenameIndex',
                                                 'django.db.migrations.operations.RenameModel': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.RenameModel',
                                                 'django.db.migrations.operations.RunPython': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.RunPython',
                                                 'django.db.migrations.operations.RunPython.noop': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.RunPython.noop',
                                                 'django.db.migrations.operations.RunSQL': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.RunSQL',
                                                 'django.db.migrations.operations.SeparateDatabaseAndState': 'http://django.readthedocs.org/en/latest/ref/migration-operations.html#django.db.migrations.operations.SeparateDatabaseAndState'},
            'django.db.models': { 'django.db.models.Aggregate': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Aggregate',
                                  'django.db.models.AutoField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.AutoField',
                                  'django.db.models.Avg': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.Avg',
                                  'django.db.models.BaseConstraint': 'http://django.readthedocs.org/en/latest/ref/models/constraints.html#django.db.models.BaseConstraint',
                                  'django.db.models.BaseConstraint.validate': 'http://django.readthedocs.org/en/latest/ref/models/constraints.html#django.db.models.BaseConstraint.validate',
                                  'django.db.models.BigAutoField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.BigAutoField',
                                  'django.db.models.BigIntegerField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.BigIntegerField',
                                  'django.db.models.BinaryField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.BinaryField',
                                  'django.db.models.BooleanField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.BooleanField',
                                  'django.db.models.CharField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.CharField',
                                  'django.db.models.CheckConstraint': 'http://django.readthedocs.org/en/latest/ref/models/constraints.html#django.db.models.CheckConstraint',
                                  'django.db.models.Count': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.Count',
                                  'django.db.models.CursorWrapper.callproc': 'http://django.readthedocs.org/en/latest/topics/db/sql.html#django.db.models.CursorWrapper.callproc',
                                  'django.db.models.DateField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.DateField',
                                  'django.db.models.DateTimeField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.DateTimeField',
                                  'django.db.models.DecimalField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.DecimalField',
                                  'django.db.models.DurationField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.DurationField',
                                  'django.db.models.EmailField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.EmailField',
                                  'django.db.models.Exists': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Exists',
                                  'django.db.models.Expression': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Expression',
                                  'django.db.models.Expression.asc': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Expression.asc',
                                  'django.db.models.Expression.convert_value': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Expression.convert_value',
                                  'django.db.models.Expression.desc': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Expression.desc',
                                  'django.db.models.Expression.get_group_by_cols': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Expression.get_group_by_cols',
                                  'django.db.models.Expression.get_source_expressions': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Expression.get_source_expressions',
                                  'django.db.models.Expression.relabeled_clone': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Expression.relabeled_clone',
                                  'django.db.models.Expression.resolve_expression': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Expression.resolve_expression',
                                  'django.db.models.Expression.reverse_ordering': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Expression.reverse_ordering',
                                  'django.db.models.Expression.set_source_expressions': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Expression.set_source_expressions',
                                  'django.db.models.ExpressionWrapper': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.ExpressionWrapper',
                                  'django.db.models.F': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.F',
                                  'django.db.models.Field': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field',
                                  'django.db.models.Field.db_type': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.db_type',
                                  'django.db.models.Field.deconstruct': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.deconstruct',
                                  'django.db.models.Field.formfield': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.formfield',
                                  'django.db.models.Field.from_db_value': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.from_db_value',
                                  'django.db.models.Field.get_db_prep_save': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.get_db_prep_save',
                                  'django.db.models.Field.get_db_prep_value': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.get_db_prep_value',
                                  'django.db.models.Field.get_internal_type': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.get_internal_type',
                                  'django.db.models.Field.get_prep_value': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.get_prep_value',
                                  'django.db.models.Field.pre_save': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.pre_save',
                                  'django.db.models.Field.rel_db_type': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.rel_db_type',
                                  'django.db.models.Field.to_python': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.to_python',
                                  'django.db.models.Field.value_from_object': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.value_from_object',
                                  'django.db.models.Field.value_to_string': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.Field.value_to_string',
                                  'django.db.models.FileField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.FileField',
                                  'django.db.models.FilePathField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.FilePathField',
                                  'django.db.models.FilteredRelation': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.FilteredRelation',
                                  'django.db.models.FloatField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.FloatField',
                                  'django.db.models.ForeignKey': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.ForeignKey',
                                  'django.db.models.Func': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Func',
                                  'django.db.models.Func.as_sql': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Func.as_sql',
                                  'django.db.models.GenericIPAddressField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.GenericIPAddressField',
                                  'django.db.models.ImageField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.ImageField',
                                  'django.db.models.Index': 'http://django.readthedocs.org/en/latest/ref/models/indexes.html#django.db.models.Index',
                                  'django.db.models.IntegerField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.IntegerField',
                                  'django.db.models.JSONField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.JSONField',
                                  'django.db.models.Lookup': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.Lookup',
                                  'django.db.models.Lookup.process_lhs': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.Lookup.process_lhs',
                                  'django.db.models.Lookup.process_rhs': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.Lookup.process_rhs',
                                  'django.db.models.Manager': 'http://django.readthedocs.org/en/latest/topics/db/managers.html#django.db.models.Manager',
                                  'django.db.models.Manager.raw': 'http://django.readthedocs.org/en/latest/topics/db/sql.html#django.db.models.Manager.raw',
                                  'django.db.models.ManyToManyField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.ManyToManyField',
                                  'django.db.models.Max': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.Max',
                                  'django.db.models.Min': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.Min',
                                  'django.db.models.Model': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model',
                                  'django.db.models.Model.__eq__': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.__eq__',
                                  'django.db.models.Model.__hash__': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.__hash__',
                                  'django.db.models.Model.__str__': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.__str__',
                                  'django.db.models.Model.adelete': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.adelete',
                                  'django.db.models.Model.arefresh_from_db': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.arefresh_from_db',
                                  'django.db.models.Model.asave': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.asave',
                                  'django.db.models.Model.clean': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.clean',
                                  'django.db.models.Model.clean_fields': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.clean_fields',
                                  'django.db.models.Model.delete': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.delete',
                                  'django.db.models.Model.from_db': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.from_db',
                                  'django.db.models.Model.full_clean': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.full_clean',
                                  'django.db.models.Model.get_FOO_display': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.get_FOO_display',
                                  'django.db.models.Model.get_absolute_url': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.get_absolute_url',
                                  'django.db.models.Model.get_deferred_fields': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.get_deferred_fields',
                                  'django.db.models.Model.get_next_by_FOO': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.get_next_by_FOO',
                                  'django.db.models.Model.get_previous_by_FOO': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.get_previous_by_FOO',
                                  'django.db.models.Model.refresh_from_db': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.refresh_from_db',
                                  'django.db.models.Model.save': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.save',
                                  'django.db.models.Model.validate_constraints': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.validate_constraints',
                                  'django.db.models.Model.validate_unique': 'http://django.readthedocs.org/en/latest/ref/models/instances.html#django.db.models.Model.validate_unique',
                                  'django.db.models.OneToOneField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.OneToOneField',
                                  'django.db.models.OuterRef': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.OuterRef',
                                  'django.db.models.PositiveBigIntegerField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.PositiveBigIntegerField',
                                  'django.db.models.PositiveIntegerField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.PositiveIntegerField',
                                  'django.db.models.PositiveSmallIntegerField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.PositiveSmallIntegerField',
                                  'django.db.models.Prefetch': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.Prefetch',
                                  'django.db.models.Q': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.Q',
                                  'django.db.models.SET': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.SET',
                                  'django.db.models.SlugField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.SlugField',
                                  'django.db.models.SmallAutoField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.SmallAutoField',
                                  'django.db.models.SmallIntegerField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.SmallIntegerField',
                                  'django.db.models.StdDev': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.StdDev',
                                  'django.db.models.Subquery': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Subquery',
                                  'django.db.models.Sum': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.Sum',
                                  'django.db.models.TextField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.TextField',
                                  'django.db.models.TimeField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.TimeField',
                                  'django.db.models.Transform': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.Transform',
                                  'django.db.models.URLField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.URLField',
                                  'django.db.models.UUIDField': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.UUIDField',
                                  'django.db.models.UniqueConstraint': 'http://django.readthedocs.org/en/latest/ref/models/constraints.html#django.db.models.UniqueConstraint',
                                  'django.db.models.Value': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.Value',
                                  'django.db.models.Variance': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.Variance',
                                  'django.db.models.constraints': 'http://django.readthedocs.org/en/latest/ref/models/constraints.html#module-django.db.models.constraints',
                                  'django.db.models.fields': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#module-django.db.models.fields',
                                  'django.db.models.functions': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#module-django.db.models.functions',
                                  'django.db.models.indexes': 'http://django.readthedocs.org/en/latest/ref/models/indexes.html#module-django.db.models.indexes',
                                  'django.db.models.lookups': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#module-django.db.models.lookups',
                                  'django.db.models.options': 'http://django.readthedocs.org/en/latest/ref/models/meta.html#module-django.db.models.options',
                                  'django.db.models.prefetch_related_objects': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.prefetch_related_objects',
                                  'django.db.models.signals': 'http://django.readthedocs.org/en/latest/ref/signals.html#module-django.db.models.signals'},
            'django.db.models.expressions': { 'django.db.models.expressions.Case': 'http://django.readthedocs.org/en/latest/ref/models/conditional-expressions.html#django.db.models.expressions.Case',
                                              'django.db.models.expressions.RawSQL': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.expressions.RawSQL',
                                              'django.db.models.expressions.RowRange': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.expressions.RowRange',
                                              'django.db.models.expressions.ValueRange': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.expressions.ValueRange',
                                              'django.db.models.expressions.When': 'http://django.readthedocs.org/en/latest/ref/models/conditional-expressions.html#django.db.models.expressions.When',
                                              'django.db.models.expressions.Window': 'http://django.readthedocs.org/en/latest/ref/models/expressions.html#django.db.models.expressions.Window'},
            'django.db.models.fields': { 'django.db.models.fields.json': 'http://django.readthedocs.org/en/latest/topics/db/queries.html#module-django.db.models.fields.json',
                                         'django.db.models.fields.related': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#module-django.db.models.fields.related'},
            'django.db.models.fields.files': { 'django.db.models.fields.files.FieldFile': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.fields.files.FieldFile',
                                               'django.db.models.fields.files.FieldFile.close': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.fields.files.FieldFile.close',
                                               'django.db.models.fields.files.FieldFile.delete': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.fields.files.FieldFile.delete',
                                               'django.db.models.fields.files.FieldFile.open': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.fields.files.FieldFile.open',
                                               'django.db.models.fields.files.FieldFile.save': 'http://django.readthedocs.org/en/latest/ref/models/fields.html#django.db.models.fields.files.FieldFile.save'},
            'django.db.models.fields.json': { 'django.db.models.fields.json.KT': 'http://django.readthedocs.org/en/latest/topics/db/queries.html#django.db.models.fields.json.KT'},
            'django.db.models.fields.related': { 'django.db.models.fields.related.RelatedManager': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager',
                                                 'django.db.models.fields.related.RelatedManager.aadd': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager.aadd',
                                                 'django.db.models.fields.related.RelatedManager.aclear': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager.aclear',
                                                 'django.db.models.fields.related.RelatedManager.acreate': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager.acreate',
                                                 'django.db.models.fields.related.RelatedManager.add': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager.add',
                                                 'django.db.models.fields.related.RelatedManager.aremove': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager.aremove',
                                                 'django.db.models.fields.related.RelatedManager.aset': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager.aset',
                                                 'django.db.models.fields.related.RelatedManager.clear': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager.clear',
                                                 'django.db.models.fields.related.RelatedManager.create': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager.create',
                                                 'django.db.models.fields.related.RelatedManager.remove': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager.remove',
                                                 'django.db.models.fields.related.RelatedManager.set': 'http://django.readthedocs.org/en/latest/ref/models/relations.html#django.db.models.fields.related.RelatedManager.set'},
            'django.db.models.functions': { 'django.db.models.functions.ACos': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ACos',
                                            'django.db.models.functions.ASin': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ASin',
                                            'django.db.models.functions.ATan': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ATan',
                                            'django.db.models.functions.ATan2': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ATan2',
                                            'django.db.models.functions.Abs': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Abs',
                                            'django.db.models.functions.Cast': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Cast',
                                            'django.db.models.functions.Ceil': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Ceil',
                                            'django.db.models.functions.Chr': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Chr',
                                            'django.db.models.functions.Coalesce': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Coalesce',
                                            'django.db.models.functions.Collate': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Collate',
                                            'django.db.models.functions.Concat': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Concat',
                                            'django.db.models.functions.Cos': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Cos',
                                            'django.db.models.functions.Cot': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Cot',
                                            'django.db.models.functions.CumeDist': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.CumeDist',
                                            'django.db.models.functions.Degrees': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Degrees',
                                            'django.db.models.functions.DenseRank': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.DenseRank',
                                            'django.db.models.functions.Exp': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Exp',
                                            'django.db.models.functions.Extract': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Extract',
                                            'django.db.models.functions.ExtractDay': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractDay',
                                            'django.db.models.functions.ExtractHour': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractHour',
                                            'django.db.models.functions.ExtractIsoWeekDay': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractIsoWeekDay',
                                            'django.db.models.functions.ExtractIsoYear': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractIsoYear',
                                            'django.db.models.functions.ExtractMinute': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractMinute',
                                            'django.db.models.functions.ExtractMonth': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractMonth',
                                            'django.db.models.functions.ExtractQuarter': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractQuarter',
                                            'django.db.models.functions.ExtractSecond': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractSecond',
                                            'django.db.models.functions.ExtractWeek': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractWeek',
                                            'django.db.models.functions.ExtractWeekDay': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractWeekDay',
                                            'django.db.models.functions.ExtractYear': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.ExtractYear',
                                            'django.db.models.functions.FirstValue': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.FirstValue',
                                            'django.db.models.functions.Floor': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Floor',
                                            'django.db.models.functions.Greatest': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Greatest',
                                            'django.db.models.functions.JSONObject': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.JSONObject',
                                            'django.db.models.functions.LPad': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.LPad',
                                            'django.db.models.functions.LTrim': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.LTrim',
                                            'django.db.models.functions.Lag': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Lag',
                                            'django.db.models.functions.LastValue': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.LastValue',
                                            'django.db.models.functions.Lead': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Lead',
                                            'django.db.models.functions.Least': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Least',
                                            'django.db.models.functions.Left': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Left',
                                            'django.db.models.functions.Length': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Length',
                                            'django.db.models.functions.Ln': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Ln',
                                            'django.db.models.functions.Log': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Log',
                                            'django.db.models.functions.Lower': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Lower',
                                            'django.db.models.functions.MD5': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.MD5',
                                            'django.db.models.functions.Mod': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Mod',
                                            'django.db.models.functions.Now': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Now',
                                            'django.db.models.functions.NthValue': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.NthValue',
                                            'django.db.models.functions.Ntile': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Ntile',
                                            'django.db.models.functions.NullIf': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.NullIf',
                                            'django.db.models.functions.Ord': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Ord',
                                            'django.db.models.functions.PercentRank': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.PercentRank',
                                            'django.db.models.functions.Pi': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Pi',
                                            'django.db.models.functions.Power': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Power',
                                            'django.db.models.functions.RPad': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.RPad',
                                            'django.db.models.functions.RTrim': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.RTrim',
                                            'django.db.models.functions.Radians': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Radians',
                                            'django.db.models.functions.Random': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Random',
                                            'django.db.models.functions.Rank': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Rank',
                                            'django.db.models.functions.Repeat': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Repeat',
                                            'django.db.models.functions.Replace': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Replace',
                                            'django.db.models.functions.Reverse': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Reverse',
                                            'django.db.models.functions.Right': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Right',
                                            'django.db.models.functions.Round': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Round',
                                            'django.db.models.functions.RowNumber': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.RowNumber',
                                            'django.db.models.functions.SHA1': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.SHA1',
                                            'django.db.models.functions.SHA224': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.SHA224',
                                            'django.db.models.functions.SHA256': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.SHA256',
                                            'django.db.models.functions.SHA384': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.SHA384',
                                            'django.db.models.functions.SHA512': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.SHA512',
                                            'django.db.models.functions.Sign': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Sign',
                                            'django.db.models.functions.Sin': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Sin',
                                            'django.db.models.functions.Sqrt': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Sqrt',
                                            'django.db.models.functions.StrIndex': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.StrIndex',
                                            'django.db.models.functions.Substr': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Substr',
                                            'django.db.models.functions.Tan': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Tan',
                                            'django.db.models.functions.Trim': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Trim',
                                            'django.db.models.functions.Trunc': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Trunc',
                                            'django.db.models.functions.TruncDate': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.TruncDate',
                                            'django.db.models.functions.TruncDay': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.TruncDay',
                                            'django.db.models.functions.TruncHour': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.TruncHour',
                                            'django.db.models.functions.TruncMinute': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.TruncMinute',
                                            'django.db.models.functions.TruncMonth': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.TruncMonth',
                                            'django.db.models.functions.TruncQuarter': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.TruncQuarter',
                                            'django.db.models.functions.TruncSecond': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.TruncSecond',
                                            'django.db.models.functions.TruncTime': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.TruncTime',
                                            'django.db.models.functions.TruncWeek': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.TruncWeek',
                                            'django.db.models.functions.TruncYear': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.TruncYear',
                                            'django.db.models.functions.Upper': 'http://django.readthedocs.org/en/latest/ref/models/database-functions.html#django.db.models.functions.Upper'},
            'django.db.models.lookups': { 'django.db.models.lookups.RegisterLookupMixin': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.lookups.RegisterLookupMixin',
                                          'django.db.models.lookups.RegisterLookupMixin.get_lookup': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.lookups.RegisterLookupMixin.get_lookup',
                                          'django.db.models.lookups.RegisterLookupMixin.get_lookups': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.lookups.RegisterLookupMixin.get_lookups',
                                          'django.db.models.lookups.RegisterLookupMixin.get_transform': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.lookups.RegisterLookupMixin.get_transform',
                                          'django.db.models.lookups.RegisterLookupMixin.register_lookup': 'http://django.readthedocs.org/en/latest/ref/models/lookups.html#django.db.models.lookups.RegisterLookupMixin.register_lookup'},
            'django.db.models.options': { 'django.db.models.options.Options': 'http://django.readthedocs.org/en/latest/ref/models/meta.html#django.db.models.options.Options',
                                          'django.db.models.options.Options.get_field': 'http://django.readthedocs.org/en/latest/ref/models/meta.html#django.db.models.options.Options.get_field',
                                          'django.db.models.options.Options.get_fields': 'http://django.readthedocs.org/en/latest/ref/models/meta.html#django.db.models.options.Options.get_fields'},
            'django.db.models.query': { 'django.db.models.query.QuerySet': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet',
                                        'django.db.models.query.QuerySet.aaggregate': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.aaggregate',
                                        'django.db.models.query.QuerySet.abulk_create': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.abulk_create',
                                        'django.db.models.query.QuerySet.abulk_update': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.abulk_update',
                                        'django.db.models.query.QuerySet.acontains': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.acontains',
                                        'django.db.models.query.QuerySet.acount': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.acount',
                                        'django.db.models.query.QuerySet.acreate': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.acreate',
                                        'django.db.models.query.QuerySet.adelete': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.adelete',
                                        'django.db.models.query.QuerySet.aearliest': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.aearliest',
                                        'django.db.models.query.QuerySet.aexists': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.aexists',
                                        'django.db.models.query.QuerySet.aexplain': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.aexplain',
                                        'django.db.models.query.QuerySet.afirst': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.afirst',
                                        'django.db.models.query.QuerySet.aget': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.aget',
                                        'django.db.models.query.QuerySet.aget_or_create': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.aget_or_create',
                                        'django.db.models.query.QuerySet.aggregate': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.aggregate',
                                        'django.db.models.query.QuerySet.ain_bulk': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.ain_bulk',
                                        'django.db.models.query.QuerySet.aiterator': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.aiterator',
                                        'django.db.models.query.QuerySet.alast': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.alast',
                                        'django.db.models.query.QuerySet.alatest': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.alatest',
                                        'django.db.models.query.QuerySet.alias': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.alias',
                                        'django.db.models.query.QuerySet.all': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.all',
                                        'django.db.models.query.QuerySet.annotate': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.annotate',
                                        'django.db.models.query.QuerySet.as_manager': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.as_manager',
                                        'django.db.models.query.QuerySet.aupdate': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.aupdate',
                                        'django.db.models.query.QuerySet.aupdate_or_create': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.aupdate_or_create',
                                        'django.db.models.query.QuerySet.bulk_create': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.bulk_create',
                                        'django.db.models.query.QuerySet.bulk_update': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.bulk_update',
                                        'django.db.models.query.QuerySet.contains': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.contains',
                                        'django.db.models.query.QuerySet.count': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.count',
                                        'django.db.models.query.QuerySet.create': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.create',
                                        'django.db.models.query.QuerySet.dates': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.dates',
                                        'django.db.models.query.QuerySet.datetimes': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.datetimes',
                                        'django.db.models.query.QuerySet.defer': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.defer',
                                        'django.db.models.query.QuerySet.delete': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.delete',
                                        'django.db.models.query.QuerySet.difference': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.difference',
                                        'django.db.models.query.QuerySet.distinct': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.distinct',
                                        'django.db.models.query.QuerySet.earliest': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.earliest',
                                        'django.db.models.query.QuerySet.exclude': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.exclude',
                                        'django.db.models.query.QuerySet.exists': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.exists',
                                        'django.db.models.query.QuerySet.explain': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.explain',
                                        'django.db.models.query.QuerySet.extra': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.extra',
                                        'django.db.models.query.QuerySet.filter': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.filter',
                                        'django.db.models.query.QuerySet.first': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.first',
                                        'django.db.models.query.QuerySet.get': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.get',
                                        'django.db.models.query.QuerySet.get_or_create': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.get_or_create',
                                        'django.db.models.query.QuerySet.in_bulk': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.in_bulk',
                                        'django.db.models.query.QuerySet.intersection': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.intersection',
                                        'django.db.models.query.QuerySet.iterator': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.iterator',
                                        'django.db.models.query.QuerySet.last': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.last',
                                        'django.db.models.query.QuerySet.latest': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.latest',
                                        'django.db.models.query.QuerySet.none': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.none',
                                        'django.db.models.query.QuerySet.only': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.only',
                                        'django.db.models.query.QuerySet.order_by': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.order_by',
                                        'django.db.models.query.QuerySet.prefetch_related': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.prefetch_related',
                                        'django.db.models.query.QuerySet.raw': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.raw',
                                        'django.db.models.query.QuerySet.reverse': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.reverse',
                                        'django.db.models.query.QuerySet.select_for_update': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.select_for_update',
                                        'django.db.models.query.QuerySet.select_related': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.select_related',
                                        'django.db.models.query.QuerySet.union': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.union',
                                        'django.db.models.query.QuerySet.update': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.update',
                                        'django.db.models.query.QuerySet.update_or_create': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.update_or_create',
                                        'django.db.models.query.QuerySet.using': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.using',
                                        'django.db.models.query.QuerySet.values': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.values',
                                        'django.db.models.query.QuerySet.values_list': 'http://django.readthedocs.org/en/latest/ref/models/querysets.html#django.db.models.query.QuerySet.values_list'},
            'django.db.transaction': { 'django.db.transaction.atomic': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.atomic',
                                       'django.db.transaction.clean_savepoints': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.clean_savepoints',
                                       'django.db.transaction.commit': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.commit',
                                       'django.db.transaction.get_autocommit': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.get_autocommit',
                                       'django.db.transaction.get_rollback': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.get_rollback',
                                       'django.db.transaction.non_atomic_requests': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.non_atomic_requests',
                                       'django.db.transaction.on_commit': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.on_commit',
                                       'django.db.transaction.rollback': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.rollback',
                                       'django.db.transaction.savepoint': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.savepoint',
                                       'django.db.transaction.savepoint_commit': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.savepoint_commit',
                                       'django.db.transaction.savepoint_rollback': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.savepoint_rollback',
                                       'django.db.transaction.set_autocommit': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.set_autocommit',
                                       'django.db.transaction.set_rollback': 'http://django.readthedocs.org/en/latest/topics/db/transactions.html#django.db.transaction.set_rollback'},
            'django.dispatch': { 'django.dispatch.Signal': 'http://django.readthedocs.org/en/latest/topics/signals.html#django.dispatch.Signal',
                                 'django.dispatch.Signal.connect': 'http://django.readthedocs.org/en/latest/topics/signals.html#django.dispatch.Signal.connect',
                                 'django.dispatch.Signal.disconnect': 'http://django.readthedocs.org/en/latest/topics/signals.html#django.dispatch.Signal.disconnect',
                                 'django.dispatch.Signal.send': 'http://django.readthedocs.org/en/latest/topics/signals.html#django.dispatch.Signal.send',
                                 'django.dispatch.Signal.send_robust': 'http://django.readthedocs.org/en/latest/topics/signals.html#django.dispatch.Signal.send_robust',
                                 'django.dispatch.receiver': 'http://django.readthedocs.org/en/latest/topics/signals.html#django.dispatch.receiver'},
            'django.forms': { 'django.forms.BooleanField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.BooleanField',
                              'django.forms.BoundField': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.BoundField',
                              'django.forms.BoundField.as_hidden': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.BoundField.as_hidden',
                              'django.forms.BoundField.as_widget': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.BoundField.as_widget',
                              'django.forms.BoundField.css_classes': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.BoundField.css_classes',
                              'django.forms.BoundField.label_tag': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.BoundField.label_tag',
                              'django.forms.BoundField.legend_tag': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.BoundField.legend_tag',
                              'django.forms.BoundField.value': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.BoundField.value',
                              'django.forms.CharField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.CharField',
                              'django.forms.CheckboxInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.CheckboxInput',
                              'django.forms.CheckboxSelectMultiple': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.CheckboxSelectMultiple',
                              'django.forms.ChoiceField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.ChoiceField',
                              'django.forms.ClearableFileInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.ClearableFileInput',
                              'django.forms.ComboField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.ComboField',
                              'django.forms.DateField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.DateField',
                              'django.forms.DateInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.DateInput',
                              'django.forms.DateTimeField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.DateTimeField',
                              'django.forms.DateTimeInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.DateTimeInput',
                              'django.forms.DecimalField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.DecimalField',
                              'django.forms.DurationField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.DurationField',
                              'django.forms.EmailField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.EmailField',
                              'django.forms.EmailInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.EmailInput',
                              'django.forms.ErrorList': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.ErrorList',
                              'django.forms.ErrorList.as_text': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.ErrorList.as_text',
                              'django.forms.ErrorList.as_ul': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.ErrorList.as_ul',
                              'django.forms.ErrorList.get_context': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.ErrorList.get_context',
                              'django.forms.ErrorList.render': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.ErrorList.render',
                              'django.forms.Field': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.Field',
                              'django.forms.Field.clean': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.Field.clean',
                              'django.forms.Field.get_bound_field': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Field.get_bound_field',
                              'django.forms.Field.has_changed': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.Field.has_changed',
                              'django.forms.FileField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.FileField',
                              'django.forms.FileInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.FileInput',
                              'django.forms.FilePathField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.FilePathField',
                              'django.forms.FloatField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.FloatField',
                              'django.forms.Form': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form',
                              'django.forms.Form.add_error': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.add_error',
                              'django.forms.Form.as_div': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.as_div',
                              'django.forms.Form.as_p': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.as_p',
                              'django.forms.Form.as_table': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.as_table',
                              'django.forms.Form.as_ul': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.as_ul',
                              'django.forms.Form.clean': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.clean',
                              'django.forms.Form.get_context': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.get_context',
                              'django.forms.Form.get_initial_for_field': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.get_initial_for_field',
                              'django.forms.Form.has_changed': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.has_changed',
                              'django.forms.Form.has_error': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.has_error',
                              'django.forms.Form.is_multipart': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.is_multipart',
                              'django.forms.Form.is_valid': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.is_valid',
                              'django.forms.Form.non_field_errors': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.non_field_errors',
                              'django.forms.Form.order_fields': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.order_fields',
                              'django.forms.Form.render': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.render',
                              'django.forms.GenericIPAddressField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.GenericIPAddressField',
                              'django.forms.HiddenInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.HiddenInput',
                              'django.forms.ImageField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.ImageField',
                              'django.forms.IntegerField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.IntegerField',
                              'django.forms.JSONField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.JSONField',
                              'django.forms.ModelChoiceField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.ModelChoiceField',
                              'django.forms.ModelChoiceIterator': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.ModelChoiceIterator',
                              'django.forms.ModelChoiceIterator.__iter__': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.ModelChoiceIterator.__iter__',
                              'django.forms.ModelChoiceIteratorValue': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.ModelChoiceIteratorValue',
                              'django.forms.ModelChoiceIteratorValue.__str__': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.ModelChoiceIteratorValue.__str__',
                              'django.forms.ModelForm': 'http://django.readthedocs.org/en/latest/topics/forms/modelforms.html#django.forms.ModelForm',
                              'django.forms.ModelMultipleChoiceField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.ModelMultipleChoiceField',
                              'django.forms.MultiValueField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.MultiValueField',
                              'django.forms.MultiValueField.compress': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.MultiValueField.compress',
                              'django.forms.MultiWidget': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.MultiWidget',
                              'django.forms.MultiWidget.decompress': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.MultiWidget.decompress',
                              'django.forms.MultiWidget.get_context': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.MultiWidget.get_context',
                              'django.forms.MultipleChoiceField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.MultipleChoiceField',
                              'django.forms.MultipleHiddenInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.MultipleHiddenInput',
                              'django.forms.NullBooleanField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.NullBooleanField',
                              'django.forms.NullBooleanSelect': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.NullBooleanSelect',
                              'django.forms.NumberInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.NumberInput',
                              'django.forms.PasswordInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.PasswordInput',
                              'django.forms.RadioSelect': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.RadioSelect',
                              'django.forms.RegexField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.RegexField',
                              'django.forms.Select': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.Select',
                              'django.forms.SelectDateWidget': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.SelectDateWidget',
                              'django.forms.SelectMultiple': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.SelectMultiple',
                              'django.forms.SlugField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.SlugField',
                              'django.forms.SplitDateTimeField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.SplitDateTimeField',
                              'django.forms.SplitDateTimeWidget': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.SplitDateTimeWidget',
                              'django.forms.SplitHiddenDateTimeWidget': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.SplitHiddenDateTimeWidget',
                              'django.forms.TextInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.TextInput',
                              'django.forms.Textarea': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.Textarea',
                              'django.forms.TimeField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.TimeField',
                              'django.forms.TimeInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.TimeInput',
                              'django.forms.TypedChoiceField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.TypedChoiceField',
                              'django.forms.TypedMultipleChoiceField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.TypedMultipleChoiceField',
                              'django.forms.URLField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.URLField',
                              'django.forms.URLInput': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.URLInput',
                              'django.forms.UUIDField': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#django.forms.UUIDField',
                              'django.forms.Widget': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.Widget',
                              'django.forms.Widget.format_value': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.Widget.format_value',
                              'django.forms.Widget.get_context': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.Widget.get_context',
                              'django.forms.Widget.id_for_label': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.Widget.id_for_label',
                              'django.forms.Widget.render': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.Widget.render',
                              'django.forms.Widget.use_required_attribute': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.Widget.use_required_attribute',
                              'django.forms.Widget.value_from_datadict': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.Widget.value_from_datadict',
                              'django.forms.Widget.value_omitted_from_data': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#django.forms.Widget.value_omitted_from_data',
                              'django.forms.fields': 'http://django.readthedocs.org/en/latest/ref/forms/fields.html#module-django.forms.fields',
                              'django.forms.formsets': 'http://django.readthedocs.org/en/latest/ref/forms/formsets.html#module-django.forms.formsets',
                              'django.forms.models': 'http://django.readthedocs.org/en/latest/ref/forms/models.html#module-django.forms.models',
                              'django.forms.renderers': 'http://django.readthedocs.org/en/latest/ref/forms/renderers.html#module-django.forms.renderers',
                              'django.forms.widgets': 'http://django.readthedocs.org/en/latest/ref/forms/widgets.html#module-django.forms.widgets'},
            'django.forms.Form': { 'django.forms.Form.errors.as_data': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.errors.as_data',
                                   'django.forms.Form.errors.as_json': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.errors.as_json',
                                   'django.forms.Form.errors.get_json_data': 'http://django.readthedocs.org/en/latest/ref/forms/api.html#django.forms.Form.errors.get_json_data'},
            'django.forms.formsets': { 'django.forms.formsets.BaseFormSet': 'http://django.readthedocs.org/en/latest/topics/forms/formsets.html#django.forms.formsets.BaseFormSet',
                                       'django.forms.formsets.BaseFormSet.as_p': 'http://django.readthedocs.org/en/latest/topics/forms/formsets.html#django.forms.formsets.BaseFormSet.as_p',
                                       'django.forms.formsets.BaseFormSet.as_table': 'http://django.readthedocs.org/en/latest/topics/forms/formsets.html#django.forms.formsets.BaseFormSet.as_table',
                                       'django.forms.formsets.BaseFormSet.as_ul': 'http://django.readthedocs.org/en/latest/topics/forms/formsets.html#django.forms.formsets.BaseFormSet.as_ul',
                                       'django.forms.formsets.BaseFormSet.get_context': 'http://django.readthedocs.org/en/latest/topics/forms/formsets.html#django.forms.formsets.BaseFormSet.get_context',
                                       'django.forms.formsets.BaseFormSet.get_deletion_widget': 'http://django.readthedocs.org/en/latest/topics/forms/formsets.html#django.forms.formsets.BaseFormSet.get_deletion_widget',
                                       'django.forms.formsets.BaseFormSet.get_ordering_widget': 'http://django.readthedocs.org/en/latest/topics/forms/formsets.html#django.forms.formsets.BaseFormSet.get_ordering_widget',
                                       'django.forms.formsets.BaseFormSet.render': 'http://django.readthedocs.org/en/latest/topics/forms/formsets.html#django.forms.formsets.BaseFormSet.render',
                                       'django.forms.formsets.BaseFormSet.total_error_count': 'http://django.readthedocs.org/en/latest/topics/forms/formsets.html#django.forms.formsets.BaseFormSet.total_error_count',
                                       'django.forms.formsets.formset_factory': 'http://django.readthedocs.org/en/latest/ref/forms/formsets.html#django.forms.formsets.formset_factory'},
            'django.forms.models': { 'django.forms.models.BaseInlineFormSet': 'http://django.readthedocs.org/en/latest/topics/forms/modelforms.html#django.forms.models.BaseInlineFormSet',
                                     'django.forms.models.BaseModelFormSet': 'http://django.readthedocs.org/en/latest/topics/forms/modelforms.html#django.forms.models.BaseModelFormSet',
                                     'django.forms.models.inlineformset_factory': 'http://django.readthedocs.org/en/latest/ref/forms/models.html#django.forms.models.inlineformset_factory',
                                     'django.forms.models.modelform_factory': 'http://django.readthedocs.org/en/latest/ref/forms/models.html#django.forms.models.modelform_factory',
                                     'django.forms.models.modelformset_factory': 'http://django.readthedocs.org/en/latest/ref/forms/models.html#django.forms.models.modelformset_factory'},
            'django.forms.renderers': { 'django.forms.renderers.BaseRenderer': 'http://django.readthedocs.org/en/latest/ref/forms/renderers.html#django.forms.renderers.BaseRenderer',
                                        'django.forms.renderers.BaseRenderer.get_template': 'http://django.readthedocs.org/en/latest/ref/forms/renderers.html#django.forms.renderers.BaseRenderer.get_template',
                                        'django.forms.renderers.BaseRenderer.render': 'http://django.readthedocs.org/en/latest/ref/forms/renderers.html#django.forms.renderers.BaseRenderer.render',
                                        'django.forms.renderers.DjangoDivFormRenderer': 'http://django.readthedocs.org/en/latest/ref/forms/renderers.html#django.forms.renderers.DjangoDivFormRenderer',
                                        'django.forms.renderers.DjangoTemplates': 'http://django.readthedocs.org/en/latest/ref/forms/renderers.html#django.forms.renderers.DjangoTemplates',
                                        'django.forms.renderers.Jinja2': 'http://django.readthedocs.org/en/latest/ref/forms/renderers.html#django.forms.renderers.Jinja2',
                                        'django.forms.renderers.Jinja2DivFormRenderer': 'http://django.readthedocs.org/en/latest/ref/forms/renderers.html#django.forms.renderers.Jinja2DivFormRenderer',
                                        'django.forms.renderers.TemplatesSetting': 'http://django.readthedocs.org/en/latest/ref/forms/renderers.html#django.forms.renderers.TemplatesSetting'},
            'django.http': { 'django.http.FileResponse': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.FileResponse',
                             'django.http.FileResponse.set_headers': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.FileResponse.set_headers',
                             'django.http.Http404': 'http://django.readthedocs.org/en/latest/topics/http/views.html#django.http.Http404',
                             'django.http.HttpRequest': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest',
                             'django.http.HttpRequest.__iter__': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.__iter__',
                             'django.http.HttpRequest.accepts': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.accepts',
                             'django.http.HttpRequest.build_absolute_uri': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.build_absolute_uri',
                             'django.http.HttpRequest.get_full_path': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.get_full_path',
                             'django.http.HttpRequest.get_full_path_info': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.get_full_path_info',
                             'django.http.HttpRequest.get_host': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.get_host',
                             'django.http.HttpRequest.get_port': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.get_port',
                             'django.http.HttpRequest.get_signed_cookie': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.get_signed_cookie',
                             'django.http.HttpRequest.is_secure': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.is_secure',
                             'django.http.HttpRequest.read': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.read',
                             'django.http.HttpRequest.readline': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.readline',
                             'django.http.HttpRequest.readlines': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpRequest.readlines',
                             'django.http.HttpResponse': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse',
                             'django.http.HttpResponse.__delitem__': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.__delitem__',
                             'django.http.HttpResponse.__getitem__': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.__getitem__',
                             'django.http.HttpResponse.__init__': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.__init__',
                             'django.http.HttpResponse.__setitem__': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.__setitem__',
                             'django.http.HttpResponse.close': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.close',
                             'django.http.HttpResponse.delete_cookie': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.delete_cookie',
                             'django.http.HttpResponse.flush': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.flush',
                             'django.http.HttpResponse.get': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.get',
                             'django.http.HttpResponse.getvalue': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.getvalue',
                             'django.http.HttpResponse.has_header': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.has_header',
                             'django.http.HttpResponse.items': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.items',
                             'django.http.HttpResponse.readable': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.readable',
                             'django.http.HttpResponse.seekable': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.seekable',
                             'django.http.HttpResponse.set_cookie': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.set_cookie',
                             'django.http.HttpResponse.set_signed_cookie': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.set_signed_cookie',
                             'django.http.HttpResponse.setdefault': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.setdefault',
                             'django.http.HttpResponse.tell': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.tell',
                             'django.http.HttpResponse.writable': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.writable',
                             'django.http.HttpResponse.write': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.write',
                             'django.http.HttpResponse.writelines': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponse.writelines',
                             'django.http.HttpResponseBadRequest': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponseBadRequest',
                             'django.http.HttpResponseBase': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponseBase',
                             'django.http.HttpResponseForbidden': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponseForbidden',
                             'django.http.HttpResponseGone': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponseGone',
                             'django.http.HttpResponseNotAllowed': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponseNotAllowed',
                             'django.http.HttpResponseNotFound': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponseNotFound',
                             'django.http.HttpResponseNotModified': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponseNotModified',
                             'django.http.HttpResponsePermanentRedirect': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponsePermanentRedirect',
                             'django.http.HttpResponseRedirect': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponseRedirect',
                             'django.http.HttpResponseServerError': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.HttpResponseServerError',
                             'django.http.JsonResponse': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.JsonResponse',
                             'django.http.QueryDict': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict',
                             'django.http.QueryDict.__contains__': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.__contains__',
                             'django.http.QueryDict.__getitem__': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.__getitem__',
                             'django.http.QueryDict.__init__': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.__init__',
                             'django.http.QueryDict.__setitem__': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.__setitem__',
                             'django.http.QueryDict.appendlist': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.appendlist',
                             'django.http.QueryDict.copy': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.copy',
                             'django.http.QueryDict.dict': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.dict',
                             'django.http.QueryDict.fromkeys': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.fromkeys',
                             'django.http.QueryDict.get': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.get',
                             'django.http.QueryDict.getlist': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.getlist',
                             'django.http.QueryDict.items': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.items',
                             'django.http.QueryDict.lists': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.lists',
                             'django.http.QueryDict.pop': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.pop',
                             'django.http.QueryDict.popitem': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.popitem',
                             'django.http.QueryDict.setdefault': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.setdefault',
                             'django.http.QueryDict.setlist': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.setlist',
                             'django.http.QueryDict.setlistdefault': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.setlistdefault',
                             'django.http.QueryDict.update': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.update',
                             'django.http.QueryDict.urlencode': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.urlencode',
                             'django.http.QueryDict.values': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.QueryDict.values',
                             'django.http.StreamingHttpResponse': 'http://django.readthedocs.org/en/latest/ref/request-response.html#django.http.StreamingHttpResponse'},
            'django.middleware': { 'django.middleware.cache': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.middleware.cache',
                                   'django.middleware.clickjacking': 'http://django.readthedocs.org/en/latest/ref/clickjacking.html#module-django.middleware.clickjacking',
                                   'django.middleware.common': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.middleware.common',
                                   'django.middleware.csrf': 'http://django.readthedocs.org/en/latest/ref/csrf.html#module-django.middleware.csrf',
                                   'django.middleware.gzip': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.middleware.gzip',
                                   'django.middleware.http': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.middleware.http',
                                   'django.middleware.locale': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.middleware.locale',
                                   'django.middleware.security': 'http://django.readthedocs.org/en/latest/ref/middleware.html#module-django.middleware.security'},
            'django.middleware.cache': { 'django.middleware.cache.FetchFromCacheMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.middleware.cache.FetchFromCacheMiddleware',
                                         'django.middleware.cache.UpdateCacheMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.middleware.cache.UpdateCacheMiddleware'},
            'django.middleware.clickjacking': { 'django.middleware.clickjacking.XFrameOptionsMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.middleware.clickjacking.XFrameOptionsMiddleware'},
            'django.middleware.common': { 'django.middleware.common.BrokenLinkEmailsMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.middleware.common.BrokenLinkEmailsMiddleware',
                                          'django.middleware.common.CommonMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.middleware.common.CommonMiddleware'},
            'django.middleware.csrf': { 'django.middleware.csrf.CsrfViewMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.middleware.csrf.CsrfViewMiddleware'},
            'django.middleware.gzip': { 'django.middleware.gzip.GZipMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.middleware.gzip.GZipMiddleware'},
            'django.middleware.http': { 'django.middleware.http.ConditionalGetMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.middleware.http.ConditionalGetMiddleware'},
            'django.middleware.locale': { 'django.middleware.locale.LocaleMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.middleware.locale.LocaleMiddleware'},
            'django.middleware.security': { 'django.middleware.security.SecurityMiddleware': 'http://django.readthedocs.org/en/latest/ref/middleware.html#django.middleware.security.SecurityMiddleware'},
            'django.shortcuts': { 'django.shortcuts.get_list_or_404': 'http://django.readthedocs.org/en/latest/topics/http/shortcuts.html#django.shortcuts.get_list_or_404',
                                  'django.shortcuts.get_object_or_404': 'http://django.readthedocs.org/en/latest/topics/http/shortcuts.html#django.shortcuts.get_object_or_404',
                                  'django.shortcuts.redirect': 'http://django.readthedocs.org/en/latest/topics/http/shortcuts.html#django.shortcuts.redirect',
                                  'django.shortcuts.render': 'http://django.readthedocs.org/en/latest/topics/http/shortcuts.html#django.shortcuts.render'},
            'django.template': { 'django.template.Context': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Context',
                                 'django.template.Context.flatten': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Context.flatten',
                                 'django.template.Context.get': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Context.get',
                                 'django.template.Context.pop': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Context.pop',
                                 'django.template.Context.push': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Context.push',
                                 'django.template.Context.setdefault': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Context.setdefault',
                                 'django.template.Context.update': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Context.update',
                                 'django.template.Engine': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Engine',
                                 'django.template.Engine.from_string': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Engine.from_string',
                                 'django.template.Engine.get_default': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Engine.get_default',
                                 'django.template.Engine.get_template': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Engine.get_template',
                                 'django.template.Engine.select_template': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Engine.select_template',
                                 'django.template.Library.filter': 'http://django.readthedocs.org/en/latest/howto/custom-template-tags.html#django.template.Library.filter',
                                 'django.template.Library.inclusion_tag': 'http://django.readthedocs.org/en/latest/howto/custom-template-tags.html#django.template.Library.inclusion_tag',
                                 'django.template.Library.simple_tag': 'http://django.readthedocs.org/en/latest/howto/custom-template-tags.html#django.template.Library.simple_tag',
                                 'django.template.RequestContext': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.RequestContext',
                                 'django.template.Template': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Template',
                                 'django.template.Template.render': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.Template.render',
                                 'django.template.backends': 'http://django.readthedocs.org/en/latest/topics/templates.html#module-django.template.backends',
                                 'django.template.defaultfilters.stringfilter': 'http://django.readthedocs.org/en/latest/howto/custom-template-tags.html#django.template.defaultfilters.stringfilter',
                                 'django.template.loader': 'http://django.readthedocs.org/en/latest/topics/templates.html#module-django.template.loader',
                                 'django.template.response': 'http://django.readthedocs.org/en/latest/ref/template-response.html#module-django.template.response'},
            'django.template.backends': { 'django.template.backends.django': 'http://django.readthedocs.org/en/latest/topics/templates.html#module-django.template.backends.django',
                                          'django.template.backends.jinja2': 'http://django.readthedocs.org/en/latest/topics/templates.html#module-django.template.backends.jinja2'},
            'django.template.backends.base': { 'django.template.backends.base.Template.render': 'http://django.readthedocs.org/en/latest/topics/templates.html#django.template.backends.base.Template.render'},
            'django.template.backends.django': { 'django.template.backends.django.DjangoTemplates': 'http://django.readthedocs.org/en/latest/topics/templates.html#django.template.backends.django.DjangoTemplates'},
            'django.template.backends.jinja2': { 'django.template.backends.jinja2.Jinja2': 'http://django.readthedocs.org/en/latest/topics/templates.html#django.template.backends.jinja2.Jinja2'},
            'django.template.base': { 'django.template.base.Origin': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.base.Origin'},
            'django.template.context_processors': { 'django.template.context_processors.debug': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.context_processors.debug',
                                                    'django.template.context_processors.i18n': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.context_processors.i18n',
                                                    'django.template.context_processors.static': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.context_processors.static',
                                                    'django.template.context_processors.tz': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.context_processors.tz'},
            'django.template.loader': { 'django.template.loader.get_template': 'http://django.readthedocs.org/en/latest/topics/templates.html#django.template.loader.get_template',
                                        'django.template.loader.render_to_string': 'http://django.readthedocs.org/en/latest/topics/templates.html#django.template.loader.render_to_string',
                                        'django.template.loader.select_template': 'http://django.readthedocs.org/en/latest/topics/templates.html#django.template.loader.select_template'},
            'django.template.loaders.app_directories': { 'django.template.loaders.app_directories.Loader': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.loaders.app_directories.Loader'},
            'django.template.loaders.base': { 'django.template.loaders.base.Loader': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.loaders.base.Loader',
                                              'django.template.loaders.base.Loader.get_contents': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.loaders.base.Loader.get_contents',
                                              'django.template.loaders.base.Loader.get_template': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.loaders.base.Loader.get_template',
                                              'django.template.loaders.base.Loader.get_template_sources': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.loaders.base.Loader.get_template_sources'},
            'django.template.loaders.cached': { 'django.template.loaders.cached.Loader': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.loaders.cached.Loader'},
            'django.template.loaders.filesystem': { 'django.template.loaders.filesystem.Loader': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.loaders.filesystem.Loader'},
            'django.template.loaders.locmem': { 'django.template.loaders.locmem.Loader': 'http://django.readthedocs.org/en/latest/ref/templates/api.html#django.template.loaders.locmem.Loader'},
            'django.template.response': { 'django.template.response.SimpleTemplateResponse': 'http://django.readthedocs.org/en/latest/ref/template-response.html#django.template.response.SimpleTemplateResponse',
                                          'django.template.response.SimpleTemplateResponse.__init__': 'http://django.readthedocs.org/en/latest/ref/template-response.html#django.template.response.SimpleTemplateResponse.__init__',
                                          'django.template.response.SimpleTemplateResponse.add_post_render_callback': 'http://django.readthedocs.org/en/latest/ref/template-response.html#django.template.response.SimpleTemplateResponse.add_post_render_callback',
                                          'django.template.response.SimpleTemplateResponse.render': 'http://django.readthedocs.org/en/latest/ref/template-response.html#django.template.response.SimpleTemplateResponse.render',
                                          'django.template.response.SimpleTemplateResponse.resolve_context': 'http://django.readthedocs.org/en/latest/ref/template-response.html#django.template.response.SimpleTemplateResponse.resolve_context',
                                          'django.template.response.SimpleTemplateResponse.resolve_template': 'http://django.readthedocs.org/en/latest/ref/template-response.html#django.template.response.SimpleTemplateResponse.resolve_template',
                                          'django.template.response.TemplateResponse': 'http://django.readthedocs.org/en/latest/ref/template-response.html#django.template.response.TemplateResponse',
                                          'django.template.response.TemplateResponse.__init__': 'http://django.readthedocs.org/en/latest/ref/template-response.html#django.template.response.TemplateResponse.__init__'},
            'django.test': { 'django.test.AsyncClient': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.AsyncClient',
                             'django.test.AsyncRequestFactory': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.AsyncRequestFactory',
                             'django.test.Client': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client',
                             'django.test.Client.delete': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.delete',
                             'django.test.Client.force_login': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.force_login',
                             'django.test.Client.get': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.get',
                             'django.test.Client.head': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.head',
                             'django.test.Client.login': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.login',
                             'django.test.Client.logout': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.logout',
                             'django.test.Client.options': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.options',
                             'django.test.Client.patch': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.patch',
                             'django.test.Client.post': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.post',
                             'django.test.Client.put': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.put',
                             'django.test.Client.trace': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Client.trace',
                             'django.test.LiveServerTestCase': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.LiveServerTestCase',
                             'django.test.RequestFactory': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.RequestFactory',
                             'django.test.Response': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Response',
                             'django.test.Response.json': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.Response.json',
                             'django.test.SimpleTestCase': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase',
                             'django.test.SimpleTestCase.assertContains': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertContains',
                             'django.test.SimpleTestCase.assertFieldOutput': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertFieldOutput',
                             'django.test.SimpleTestCase.assertFormError': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertFormError',
                             'django.test.SimpleTestCase.assertFormSetError': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertFormSetError',
                             'django.test.SimpleTestCase.assertHTMLEqual': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertHTMLEqual',
                             'django.test.SimpleTestCase.assertHTMLNotEqual': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertHTMLNotEqual',
                             'django.test.SimpleTestCase.assertInHTML': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertInHTML',
                             'django.test.SimpleTestCase.assertJSONEqual': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertJSONEqual',
                             'django.test.SimpleTestCase.assertJSONNotEqual': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertJSONNotEqual',
                             'django.test.SimpleTestCase.assertNotContains': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertNotContains',
                             'django.test.SimpleTestCase.assertRaisesMessage': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertRaisesMessage',
                             'django.test.SimpleTestCase.assertRedirects': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertRedirects',
                             'django.test.SimpleTestCase.assertTemplateNotUsed': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertTemplateNotUsed',
                             'django.test.SimpleTestCase.assertTemplateUsed': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertTemplateUsed',
                             'django.test.SimpleTestCase.assertURLEqual': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertURLEqual',
                             'django.test.SimpleTestCase.assertWarnsMessage': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertWarnsMessage',
                             'django.test.SimpleTestCase.assertXMLEqual': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertXMLEqual',
                             'django.test.SimpleTestCase.assertXMLNotEqual': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.assertXMLNotEqual',
                             'django.test.SimpleTestCase.modify_settings': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.modify_settings',
                             'django.test.SimpleTestCase.settings': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.SimpleTestCase.settings',
                             'django.test.TestCase': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.TestCase',
                             'django.test.TestCase.captureOnCommitCallbacks': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.TestCase.captureOnCommitCallbacks',
                             'django.test.TestCase.setUpTestData': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.TestCase.setUpTestData',
                             'django.test.TransactionTestCase': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.TransactionTestCase',
                             'django.test.TransactionTestCase.assertNumQueries': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.TransactionTestCase.assertNumQueries',
                             'django.test.TransactionTestCase.assertQuerySetEqual': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.TransactionTestCase.assertQuerySetEqual',
                             'django.test.modify_settings': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.modify_settings',
                             'django.test.override_settings': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.override_settings',
                             'django.test.signals': 'http://django.readthedocs.org/en/latest/ref/signals.html#module-django.test.signals',
                             'django.test.skipIfDBFeature': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.skipIfDBFeature',
                             'django.test.skipUnlessDBFeature': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.skipUnlessDBFeature',
                             'django.test.utils': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#module-django.test.utils'},
            'django.test.runner': { 'django.test.runner.DiscoverRunner': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner',
                                    'django.test.runner.DiscoverRunner.add_arguments': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.add_arguments',
                                    'django.test.runner.DiscoverRunner.build_suite': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.build_suite',
                                    'django.test.runner.DiscoverRunner.get_test_runner_kwargs': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.get_test_runner_kwargs',
                                    'django.test.runner.DiscoverRunner.log': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.log',
                                    'django.test.runner.DiscoverRunner.run_checks': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.run_checks',
                                    'django.test.runner.DiscoverRunner.run_suite': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.run_suite',
                                    'django.test.runner.DiscoverRunner.run_tests': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.run_tests',
                                    'django.test.runner.DiscoverRunner.setup_databases': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.setup_databases',
                                    'django.test.runner.DiscoverRunner.setup_test_environment': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.setup_test_environment',
                                    'django.test.runner.DiscoverRunner.suite_result': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.suite_result',
                                    'django.test.runner.DiscoverRunner.teardown_databases': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.teardown_databases',
                                    'django.test.runner.DiscoverRunner.teardown_test_environment': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.runner.DiscoverRunner.teardown_test_environment'},
            'django.test.utils': { 'django.test.utils.isolate_apps': 'http://django.readthedocs.org/en/latest/topics/testing/tools.html#django.test.utils.isolate_apps',
                                   'django.test.utils.setup_databases': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.utils.setup_databases',
                                   'django.test.utils.setup_test_environment': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.utils.setup_test_environment',
                                   'django.test.utils.teardown_databases': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.utils.teardown_databases',
                                   'django.test.utils.teardown_test_environment': 'http://django.readthedocs.org/en/latest/topics/testing/advanced.html#django.test.utils.teardown_test_environment'},
            'django.urls': { 'django.urls.ResolverMatch': 'http://django.readthedocs.org/en/latest/ref/urlresolvers.html#django.urls.ResolverMatch',
                             'django.urls.conf': 'http://django.readthedocs.org/en/latest/ref/urls.html#module-django.urls.conf',
                             'django.urls.get_script_prefix': 'http://django.readthedocs.org/en/latest/ref/urlresolvers.html#django.urls.get_script_prefix',
                             'django.urls.include': 'http://django.readthedocs.org/en/latest/ref/urls.html#django.urls.include',
                             'django.urls.path': 'http://django.readthedocs.org/en/latest/ref/urls.html#django.urls.path',
                             'django.urls.re_path': 'http://django.readthedocs.org/en/latest/ref/urls.html#django.urls.re_path',
                             'django.urls.register_converter': 'http://django.readthedocs.org/en/latest/ref/urls.html#django.urls.register_converter',
                             'django.urls.resolve': 'http://django.readthedocs.org/en/latest/ref/urlresolvers.html#django.urls.resolve',
                             'django.urls.reverse': 'http://django.readthedocs.org/en/latest/ref/urlresolvers.html#django.urls.reverse',
                             'django.urls.reverse_lazy': 'http://django.readthedocs.org/en/latest/ref/urlresolvers.html#django.urls.reverse_lazy'},
            'django.utils': { 'django.utils.cache': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.cache',
                              'django.utils.dateparse': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.dateparse',
                              'django.utils.decorators': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.decorators',
                              'django.utils.encoding': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.encoding',
                              'django.utils.feedgenerator': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.feedgenerator',
                              'django.utils.functional': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.functional',
                              'django.utils.html': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.html',
                              'django.utils.http': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.http',
                              'django.utils.log': 'http://django.readthedocs.org/en/latest/ref/logging.html#module-django.utils.log',
                              'django.utils.module_loading': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.module_loading',
                              'django.utils.safestring': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.safestring',
                              'django.utils.text': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.text',
                              'django.utils.timezone': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.timezone',
                              'django.utils.translation': 'http://django.readthedocs.org/en/latest/ref/utils.html#module-django.utils.translation'},
            'django.utils.cache': { 'django.utils.cache.add_never_cache_headers': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.cache.add_never_cache_headers',
                                    'django.utils.cache.get_cache_key': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.cache.get_cache_key',
                                    'django.utils.cache.get_max_age': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.cache.get_max_age',
                                    'django.utils.cache.learn_cache_key': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.cache.learn_cache_key',
                                    'django.utils.cache.patch_cache_control': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.cache.patch_cache_control',
                                    'django.utils.cache.patch_response_headers': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.cache.patch_response_headers',
                                    'django.utils.cache.patch_vary_headers': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.cache.patch_vary_headers'},
            'django.utils.dateparse': { 'django.utils.dateparse.parse_date': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.dateparse.parse_date',
                                        'django.utils.dateparse.parse_datetime': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.dateparse.parse_datetime',
                                        'django.utils.dateparse.parse_duration': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.dateparse.parse_duration',
                                        'django.utils.dateparse.parse_time': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.dateparse.parse_time'},
            'django.utils.decorators': { 'django.utils.decorators.async_only_middleware': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.decorators.async_only_middleware',
                                         'django.utils.decorators.decorator_from_middleware': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.decorators.decorator_from_middleware',
                                         'django.utils.decorators.decorator_from_middleware_with_args': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.decorators.decorator_from_middleware_with_args',
                                         'django.utils.decorators.method_decorator': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.decorators.method_decorator',
                                         'django.utils.decorators.sync_and_async_middleware': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.decorators.sync_and_async_middleware',
                                         'django.utils.decorators.sync_only_middleware': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.decorators.sync_only_middleware'},
            'django.utils.deprecation': { 'django.utils.deprecation.MiddlewareMixin': 'http://django.readthedocs.org/en/latest/topics/http/middleware.html#django.utils.deprecation.MiddlewareMixin'},
            'django.utils.encoding': { 'django.utils.encoding.escape_uri_path': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.encoding.escape_uri_path',
                                       'django.utils.encoding.filepath_to_uri': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.encoding.filepath_to_uri',
                                       'django.utils.encoding.force_bytes': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.encoding.force_bytes',
                                       'django.utils.encoding.force_str': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.encoding.force_str',
                                       'django.utils.encoding.iri_to_uri': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.encoding.iri_to_uri',
                                       'django.utils.encoding.is_protected_type': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.encoding.is_protected_type',
                                       'django.utils.encoding.smart_bytes': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.encoding.smart_bytes',
                                       'django.utils.encoding.smart_str': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.encoding.smart_str',
                                       'django.utils.encoding.uri_to_iri': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.encoding.uri_to_iri'},
            'django.utils.feedgenerator': { 'django.utils.feedgenerator.Atom1Feed': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.Atom1Feed',
                                            'django.utils.feedgenerator.Enclosure': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.Enclosure',
                                            'django.utils.feedgenerator.Rss201rev2Feed': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.Rss201rev2Feed',
                                            'django.utils.feedgenerator.RssFeed': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.RssFeed',
                                            'django.utils.feedgenerator.RssUserland091Feed': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.RssUserland091Feed',
                                            'django.utils.feedgenerator.SyndicationFeed': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed',
                                            'django.utils.feedgenerator.SyndicationFeed.__init__': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed.__init__',
                                            'django.utils.feedgenerator.SyndicationFeed.add_item': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed.add_item',
                                            'django.utils.feedgenerator.SyndicationFeed.add_item_elements': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed.add_item_elements',
                                            'django.utils.feedgenerator.SyndicationFeed.add_root_elements': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed.add_root_elements',
                                            'django.utils.feedgenerator.SyndicationFeed.item_attributes': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed.item_attributes',
                                            'django.utils.feedgenerator.SyndicationFeed.latest_post_date': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed.latest_post_date',
                                            'django.utils.feedgenerator.SyndicationFeed.num_items': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed.num_items',
                                            'django.utils.feedgenerator.SyndicationFeed.root_attributes': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed.root_attributes',
                                            'django.utils.feedgenerator.SyndicationFeed.write': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed.write',
                                            'django.utils.feedgenerator.SyndicationFeed.writeString': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.SyndicationFeed.writeString',
                                            'django.utils.feedgenerator.get_tag_uri': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.feedgenerator.get_tag_uri'},
            'django.utils.functional': { 'django.utils.functional.cached_property': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.functional.cached_property',
                                         'django.utils.functional.classproperty': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.functional.classproperty',
                                         'django.utils.functional.keep_lazy': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.functional.keep_lazy',
                                         'django.utils.functional.keep_lazy_text': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.functional.keep_lazy_text'},
            'django.utils.html': { 'django.utils.html.conditional_escape': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.html.conditional_escape',
                                   'django.utils.html.escape': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.html.escape',
                                   'django.utils.html.format_html': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.html.format_html',
                                   'django.utils.html.format_html_join': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.html.format_html_join',
                                   'django.utils.html.html_safe': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.html.html_safe',
                                   'django.utils.html.json_script': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.html.json_script',
                                   'django.utils.html.strip_tags': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.html.strip_tags'},
            'django.utils.http': { 'django.utils.http.base36_to_int': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.http.base36_to_int',
                                   'django.utils.http.content_disposition_header': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.http.content_disposition_header',
                                   'django.utils.http.http_date': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.http.http_date',
                                   'django.utils.http.int_to_base36': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.http.int_to_base36',
                                   'django.utils.http.urlencode': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.http.urlencode',
                                   'django.utils.http.urlsafe_base64_decode': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.http.urlsafe_base64_decode',
                                   'django.utils.http.urlsafe_base64_encode': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.http.urlsafe_base64_encode'},
            'django.utils.log': { 'django.utils.log.AdminEmailHandler': 'http://django.readthedocs.org/en/latest/ref/logging.html#django.utils.log.AdminEmailHandler',
                                  'django.utils.log.AdminEmailHandler.send_mail': 'http://django.readthedocs.org/en/latest/ref/logging.html#django.utils.log.AdminEmailHandler.send_mail',
                                  'django.utils.log.CallbackFilter': 'http://django.readthedocs.org/en/latest/ref/logging.html#django.utils.log.CallbackFilter',
                                  'django.utils.log.RequireDebugFalse': 'http://django.readthedocs.org/en/latest/ref/logging.html#django.utils.log.RequireDebugFalse',
                                  'django.utils.log.RequireDebugTrue': 'http://django.readthedocs.org/en/latest/ref/logging.html#django.utils.log.RequireDebugTrue'},
            'django.utils.module_loading': { 'django.utils.module_loading.import_string': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.module_loading.import_string'},
            'django.utils.safestring': { 'django.utils.safestring.SafeString': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.safestring.SafeString',
                                         'django.utils.safestring.mark_safe': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.safestring.mark_safe'},
            'django.utils.text': { 'django.utils.text.format_lazy': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.text.format_lazy',
                                   'django.utils.text.slugify': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.text.slugify'},
            'django.utils.timezone': { 'django.utils.timezone.activate': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.activate',
                                       'django.utils.timezone.deactivate': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.deactivate',
                                       'django.utils.timezone.get_current_timezone': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.get_current_timezone',
                                       'django.utils.timezone.get_current_timezone_name': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.get_current_timezone_name',
                                       'django.utils.timezone.get_default_timezone': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.get_default_timezone',
                                       'django.utils.timezone.get_default_timezone_name': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.get_default_timezone_name',
                                       'django.utils.timezone.get_fixed_timezone': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.get_fixed_timezone',
                                       'django.utils.timezone.is_aware': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.is_aware',
                                       'django.utils.timezone.is_naive': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.is_naive',
                                       'django.utils.timezone.localdate': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.localdate',
                                       'django.utils.timezone.localtime': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.localtime',
                                       'django.utils.timezone.make_aware': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.make_aware',
                                       'django.utils.timezone.make_naive': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.make_naive',
                                       'django.utils.timezone.now': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.now',
                                       'django.utils.timezone.override': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.timezone.override'},
            'django.utils.translation': { 'django.utils.translation.activate': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.activate',
                                          'django.utils.translation.check_for_language': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.check_for_language',
                                          'django.utils.translation.deactivate': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.deactivate',
                                          'django.utils.translation.deactivate_all': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.deactivate_all',
                                          'django.utils.translation.get_language': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.get_language',
                                          'django.utils.translation.get_language_bidi': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.get_language_bidi',
                                          'django.utils.translation.get_language_from_request': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.get_language_from_request',
                                          'django.utils.translation.get_language_info': 'http://django.readthedocs.org/en/latest/topics/i18n/translation.html#django.utils.translation.get_language_info',
                                          'django.utils.translation.get_supported_language_variant': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.get_supported_language_variant',
                                          'django.utils.translation.gettext': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.gettext',
                                          'django.utils.translation.gettext_lazy': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.gettext_lazy',
                                          'django.utils.translation.gettext_noop': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.gettext_noop',
                                          'django.utils.translation.ngettext': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.ngettext',
                                          'django.utils.translation.ngettext_lazy': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.ngettext_lazy',
                                          'django.utils.translation.npgettext': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.npgettext',
                                          'django.utils.translation.npgettext_lazy': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.npgettext_lazy',
                                          'django.utils.translation.override': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.override',
                                          'django.utils.translation.pgettext': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.pgettext',
                                          'django.utils.translation.pgettext_lazy': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.pgettext_lazy',
                                          'django.utils.translation.templatize': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.templatize',
                                          'django.utils.translation.to_locale': 'http://django.readthedocs.org/en/latest/ref/utils.html#django.utils.translation.to_locale'},
            'django.views': {'django.views.i18n': 'http://django.readthedocs.org/en/latest/topics/i18n/translation.html#module-django.views.i18n'},
            'django.views.debug': { 'django.views.debug.ExceptionReporter': 'http://django.readthedocs.org/en/latest/howto/error-reporting.html#django.views.debug.ExceptionReporter',
                                    'django.views.debug.ExceptionReporter.get_traceback_data': 'http://django.readthedocs.org/en/latest/howto/error-reporting.html#django.views.debug.ExceptionReporter.get_traceback_data',
                                    'django.views.debug.ExceptionReporter.get_traceback_html': 'http://django.readthedocs.org/en/latest/howto/error-reporting.html#django.views.debug.ExceptionReporter.get_traceback_html',
                                    'django.views.debug.ExceptionReporter.get_traceback_text': 'http://django.readthedocs.org/en/latest/howto/error-reporting.html#django.views.debug.ExceptionReporter.get_traceback_text',
                                    'django.views.debug.SafeExceptionReporterFilter': 'http://django.readthedocs.org/en/latest/howto/error-reporting.html#django.views.debug.SafeExceptionReporterFilter',
                                    'django.views.debug.SafeExceptionReporterFilter.get_post_parameters': 'http://django.readthedocs.org/en/latest/howto/error-reporting.html#django.views.debug.SafeExceptionReporterFilter.get_post_parameters',
                                    'django.views.debug.SafeExceptionReporterFilter.get_traceback_frame_variables': 'http://django.readthedocs.org/en/latest/howto/error-reporting.html#django.views.debug.SafeExceptionReporterFilter.get_traceback_frame_variables',
                                    'django.views.debug.SafeExceptionReporterFilter.is_active': 'http://django.readthedocs.org/en/latest/howto/error-reporting.html#django.views.debug.SafeExceptionReporterFilter.is_active'},
            'django.views.decorators': { 'django.views.decorators.cache': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#module-django.views.decorators.cache',
                                         'django.views.decorators.common': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#module-django.views.decorators.common',
                                         'django.views.decorators.csrf': 'http://django.readthedocs.org/en/latest/ref/csrf.html#module-django.views.decorators.csrf',
                                         'django.views.decorators.gzip': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#module-django.views.decorators.gzip',
                                         'django.views.decorators.http': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#module-django.views.decorators.http',
                                         'django.views.decorators.vary': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#module-django.views.decorators.vary'},
            'django.views.decorators.cache': { 'django.views.decorators.cache.cache_control': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.cache.cache_control',
                                               'django.views.decorators.cache.cache_page': 'http://django.readthedocs.org/en/latest/topics/cache.html#django.views.decorators.cache.cache_page',
                                               'django.views.decorators.cache.never_cache': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.cache.never_cache'},
            'django.views.decorators.common': { 'django.views.decorators.common.no_append_slash': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.common.no_append_slash'},
            'django.views.decorators.csrf': { 'django.views.decorators.csrf.csrf_exempt': 'http://django.readthedocs.org/en/latest/ref/csrf.html#django.views.decorators.csrf.csrf_exempt',
                                              'django.views.decorators.csrf.csrf_protect': 'http://django.readthedocs.org/en/latest/ref/csrf.html#django.views.decorators.csrf.csrf_protect',
                                              'django.views.decorators.csrf.ensure_csrf_cookie': 'http://django.readthedocs.org/en/latest/ref/csrf.html#django.views.decorators.csrf.ensure_csrf_cookie',
                                              'django.views.decorators.csrf.requires_csrf_token': 'http://django.readthedocs.org/en/latest/ref/csrf.html#django.views.decorators.csrf.requires_csrf_token'},
            'django.views.decorators.debug': { 'django.views.decorators.debug.sensitive_post_parameters': 'http://django.readthedocs.org/en/latest/howto/error-reporting.html#django.views.decorators.debug.sensitive_post_parameters',
                                               'django.views.decorators.debug.sensitive_variables': 'http://django.readthedocs.org/en/latest/howto/error-reporting.html#django.views.decorators.debug.sensitive_variables'},
            'django.views.decorators.gzip': { 'django.views.decorators.gzip.gzip_page': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.gzip.gzip_page'},
            'django.views.decorators.http': { 'django.views.decorators.http.condition': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.http.condition',
                                              'django.views.decorators.http.etag': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.http.etag',
                                              'django.views.decorators.http.last_modified': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.http.last_modified',
                                              'django.views.decorators.http.require_GET': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.http.require_GET',
                                              'django.views.decorators.http.require_POST': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.http.require_POST',
                                              'django.views.decorators.http.require_http_methods': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.http.require_http_methods',
                                              'django.views.decorators.http.require_safe': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.http.require_safe'},
            'django.views.decorators.vary': { 'django.views.decorators.vary.vary_on_cookie': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.vary.vary_on_cookie',
                                              'django.views.decorators.vary.vary_on_headers': 'http://django.readthedocs.org/en/latest/topics/http/decorators.html#django.views.decorators.vary.vary_on_headers'},
            'django.views.defaults': { 'django.views.defaults.bad_request': 'http://django.readthedocs.org/en/latest/ref/views.html#django.views.defaults.bad_request',
                                       'django.views.defaults.page_not_found': 'http://django.readthedocs.org/en/latest/ref/views.html#django.views.defaults.page_not_found',
                                       'django.views.defaults.permission_denied': 'http://django.readthedocs.org/en/latest/ref/views.html#django.views.defaults.permission_denied',
                                       'django.views.defaults.server_error': 'http://django.readthedocs.org/en/latest/ref/views.html#django.views.defaults.server_error'},
            'django.views.generic': { 'django.views.generic.dates': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#module-django.views.generic.dates'},
            'django.views.generic.base': { 'django.views.generic.base.ContextMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-simple.html#django.views.generic.base.ContextMixin',
                                           'django.views.generic.base.ContextMixin.get_context_data': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-simple.html#django.views.generic.base.ContextMixin.get_context_data',
                                           'django.views.generic.base.RedirectView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/base.html#django.views.generic.base.RedirectView',
                                           'django.views.generic.base.RedirectView.get_redirect_url': 'http://django.readthedocs.org/en/latest/ref/class-based-views/base.html#django.views.generic.base.RedirectView.get_redirect_url',
                                           'django.views.generic.base.TemplateResponseMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-simple.html#django.views.generic.base.TemplateResponseMixin',
                                           'django.views.generic.base.TemplateResponseMixin.get_template_names': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-simple.html#django.views.generic.base.TemplateResponseMixin.get_template_names',
                                           'django.views.generic.base.TemplateResponseMixin.render_to_response': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-simple.html#django.views.generic.base.TemplateResponseMixin.render_to_response',
                                           'django.views.generic.base.TemplateView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/base.html#django.views.generic.base.TemplateView',
                                           'django.views.generic.base.View': 'http://django.readthedocs.org/en/latest/ref/class-based-views/base.html#django.views.generic.base.View',
                                           'django.views.generic.base.View.as_view': 'http://django.readthedocs.org/en/latest/ref/class-based-views/base.html#django.views.generic.base.View.as_view',
                                           'django.views.generic.base.View.dispatch': 'http://django.readthedocs.org/en/latest/ref/class-based-views/base.html#django.views.generic.base.View.dispatch',
                                           'django.views.generic.base.View.http_method_not_allowed': 'http://django.readthedocs.org/en/latest/ref/class-based-views/base.html#django.views.generic.base.View.http_method_not_allowed',
                                           'django.views.generic.base.View.options': 'http://django.readthedocs.org/en/latest/ref/class-based-views/base.html#django.views.generic.base.View.options',
                                           'django.views.generic.base.View.setup': 'http://django.readthedocs.org/en/latest/ref/class-based-views/base.html#django.views.generic.base.View.setup'},
            'django.views.generic.dates': { 'django.views.generic.dates.ArchiveIndexView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.ArchiveIndexView',
                                            'django.views.generic.dates.BaseArchiveIndexView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.BaseArchiveIndexView',
                                            'django.views.generic.dates.BaseDateDetailView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.BaseDateDetailView',
                                            'django.views.generic.dates.BaseDateListView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.BaseDateListView',
                                            'django.views.generic.dates.BaseDateListView.get_date_list': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.BaseDateListView.get_date_list',
                                            'django.views.generic.dates.BaseDateListView.get_date_list_period': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.BaseDateListView.get_date_list_period',
                                            'django.views.generic.dates.BaseDateListView.get_dated_items': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.BaseDateListView.get_dated_items',
                                            'django.views.generic.dates.BaseDateListView.get_dated_queryset': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.BaseDateListView.get_dated_queryset',
                                            'django.views.generic.dates.BaseDayArchiveView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.BaseDayArchiveView',
                                            'django.views.generic.dates.BaseMonthArchiveView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.BaseMonthArchiveView',
                                            'django.views.generic.dates.BaseTodayArchiveView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.BaseTodayArchiveView',
                                            'django.views.generic.dates.BaseWeekArchiveView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.BaseWeekArchiveView',
                                            'django.views.generic.dates.BaseYearArchiveView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.BaseYearArchiveView',
                                            'django.views.generic.dates.DateDetailView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.DateDetailView',
                                            'django.views.generic.dates.DateMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.DateMixin',
                                            'django.views.generic.dates.DateMixin.get_allow_future': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.DateMixin.get_allow_future',
                                            'django.views.generic.dates.DateMixin.get_date_field': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.DateMixin.get_date_field',
                                            'django.views.generic.dates.DayArchiveView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.DayArchiveView',
                                            'django.views.generic.dates.DayMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.DayMixin',
                                            'django.views.generic.dates.DayMixin.get_day': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.DayMixin.get_day',
                                            'django.views.generic.dates.DayMixin.get_day_format': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.DayMixin.get_day_format',
                                            'django.views.generic.dates.DayMixin.get_next_day': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.DayMixin.get_next_day',
                                            'django.views.generic.dates.DayMixin.get_previous_day': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.DayMixin.get_previous_day',
                                            'django.views.generic.dates.MonthArchiveView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.MonthArchiveView',
                                            'django.views.generic.dates.MonthMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.MonthMixin',
                                            'django.views.generic.dates.MonthMixin.get_month': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.MonthMixin.get_month',
                                            'django.views.generic.dates.MonthMixin.get_month_format': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.MonthMixin.get_month_format',
                                            'django.views.generic.dates.MonthMixin.get_next_month': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.MonthMixin.get_next_month',
                                            'django.views.generic.dates.MonthMixin.get_previous_month': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.MonthMixin.get_previous_month',
                                            'django.views.generic.dates.TodayArchiveView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.TodayArchiveView',
                                            'django.views.generic.dates.WeekArchiveView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.WeekArchiveView',
                                            'django.views.generic.dates.WeekMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.WeekMixin',
                                            'django.views.generic.dates.WeekMixin.get_next_week': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.WeekMixin.get_next_week',
                                            'django.views.generic.dates.WeekMixin.get_prev_week': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.WeekMixin.get_prev_week',
                                            'django.views.generic.dates.WeekMixin.get_week': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.WeekMixin.get_week',
                                            'django.views.generic.dates.WeekMixin.get_week_format': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.WeekMixin.get_week_format',
                                            'django.views.generic.dates.YearArchiveView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.YearArchiveView',
                                            'django.views.generic.dates.YearArchiveView.get_make_object_list': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-date-based.html#django.views.generic.dates.YearArchiveView.get_make_object_list',
                                            'django.views.generic.dates.YearMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.YearMixin',
                                            'django.views.generic.dates.YearMixin.get_next_year': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.YearMixin.get_next_year',
                                            'django.views.generic.dates.YearMixin.get_previous_year': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.YearMixin.get_previous_year',
                                            'django.views.generic.dates.YearMixin.get_year': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.YearMixin.get_year',
                                            'django.views.generic.dates.YearMixin.get_year_format': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-date-based.html#django.views.generic.dates.YearMixin.get_year_format'},
            'django.views.generic.detail': { 'django.views.generic.detail.BaseDetailView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-display.html#django.views.generic.detail.BaseDetailView',
                                             'django.views.generic.detail.BaseDetailView.get': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-display.html#django.views.generic.detail.BaseDetailView.get',
                                             'django.views.generic.detail.DetailView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-display.html#django.views.generic.detail.DetailView',
                                             'django.views.generic.detail.SingleObjectMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-single-object.html#django.views.generic.detail.SingleObjectMixin',
                                             'django.views.generic.detail.SingleObjectMixin.get_context_data': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-single-object.html#django.views.generic.detail.SingleObjectMixin.get_context_data',
                                             'django.views.generic.detail.SingleObjectMixin.get_context_object_name': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-single-object.html#django.views.generic.detail.SingleObjectMixin.get_context_object_name',
                                             'django.views.generic.detail.SingleObjectMixin.get_object': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-single-object.html#django.views.generic.detail.SingleObjectMixin.get_object',
                                             'django.views.generic.detail.SingleObjectMixin.get_queryset': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-single-object.html#django.views.generic.detail.SingleObjectMixin.get_queryset',
                                             'django.views.generic.detail.SingleObjectMixin.get_slug_field': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-single-object.html#django.views.generic.detail.SingleObjectMixin.get_slug_field',
                                             'django.views.generic.detail.SingleObjectTemplateResponseMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-single-object.html#django.views.generic.detail.SingleObjectTemplateResponseMixin',
                                             'django.views.generic.detail.SingleObjectTemplateResponseMixin.get_template_names': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-single-object.html#django.views.generic.detail.SingleObjectTemplateResponseMixin.get_template_names'},
            'django.views.generic.edit': { 'django.views.generic.edit.BaseCreateView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.BaseCreateView',
                                           'django.views.generic.edit.BaseCreateView.get': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.BaseCreateView.get',
                                           'django.views.generic.edit.BaseCreateView.post': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.BaseCreateView.post',
                                           'django.views.generic.edit.BaseDeleteView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.BaseDeleteView',
                                           'django.views.generic.edit.BaseFormView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.BaseFormView',
                                           'django.views.generic.edit.BaseUpdateView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.BaseUpdateView',
                                           'django.views.generic.edit.BaseUpdateView.get': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.BaseUpdateView.get',
                                           'django.views.generic.edit.BaseUpdateView.post': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.BaseUpdateView.post',
                                           'django.views.generic.edit.CreateView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.CreateView',
                                           'django.views.generic.edit.DeleteView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.DeleteView',
                                           'django.views.generic.edit.DeletionMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.DeletionMixin',
                                           'django.views.generic.edit.DeletionMixin.delete': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.DeletionMixin.delete',
                                           'django.views.generic.edit.DeletionMixin.get_success_url': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.DeletionMixin.get_success_url',
                                           'django.views.generic.edit.FormMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.FormMixin',
                                           'django.views.generic.edit.FormMixin.form_invalid': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.FormMixin.form_invalid',
                                           'django.views.generic.edit.FormMixin.form_valid': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.FormMixin.form_valid',
                                           'django.views.generic.edit.FormMixin.get_context_data': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.FormMixin.get_context_data',
                                           'django.views.generic.edit.FormMixin.get_form': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.FormMixin.get_form',
                                           'django.views.generic.edit.FormMixin.get_form_class': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.FormMixin.get_form_class',
                                           'django.views.generic.edit.FormMixin.get_form_kwargs': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.FormMixin.get_form_kwargs',
                                           'django.views.generic.edit.FormMixin.get_initial': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.FormMixin.get_initial',
                                           'django.views.generic.edit.FormMixin.get_prefix': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.FormMixin.get_prefix',
                                           'django.views.generic.edit.FormMixin.get_success_url': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.FormMixin.get_success_url',
                                           'django.views.generic.edit.FormView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.FormView',
                                           'django.views.generic.edit.ModelFormMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.ModelFormMixin',
                                           'django.views.generic.edit.ModelFormMixin.form_invalid': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.ModelFormMixin.form_invalid',
                                           'django.views.generic.edit.ModelFormMixin.form_valid': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.ModelFormMixin.form_valid',
                                           'django.views.generic.edit.ModelFormMixin.get_form_class': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.ModelFormMixin.get_form_class',
                                           'django.views.generic.edit.ModelFormMixin.get_form_kwargs': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.ModelFormMixin.get_form_kwargs',
                                           'django.views.generic.edit.ModelFormMixin.get_success_url': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.ModelFormMixin.get_success_url',
                                           'django.views.generic.edit.ProcessFormView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.ProcessFormView',
                                           'django.views.generic.edit.ProcessFormView.get': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.ProcessFormView.get',
                                           'django.views.generic.edit.ProcessFormView.post': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.ProcessFormView.post',
                                           'django.views.generic.edit.ProcessFormView.put': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-editing.html#django.views.generic.edit.ProcessFormView.put',
                                           'django.views.generic.edit.UpdateView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-editing.html#django.views.generic.edit.UpdateView'},
            'django.views.generic.list': { 'django.views.generic.list.BaseListView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-display.html#django.views.generic.list.BaseListView',
                                           'django.views.generic.list.BaseListView.get': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-display.html#django.views.generic.list.BaseListView.get',
                                           'django.views.generic.list.ListView': 'http://django.readthedocs.org/en/latest/ref/class-based-views/generic-display.html#django.views.generic.list.ListView',
                                           'django.views.generic.list.MultipleObjectMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectMixin',
                                           'django.views.generic.list.MultipleObjectMixin.get_allow_empty': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectMixin.get_allow_empty',
                                           'django.views.generic.list.MultipleObjectMixin.get_context_data': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectMixin.get_context_data',
                                           'django.views.generic.list.MultipleObjectMixin.get_context_object_name': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectMixin.get_context_object_name',
                                           'django.views.generic.list.MultipleObjectMixin.get_ordering': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectMixin.get_ordering',
                                           'django.views.generic.list.MultipleObjectMixin.get_paginate_by': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectMixin.get_paginate_by',
                                           'django.views.generic.list.MultipleObjectMixin.get_paginate_orphans': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectMixin.get_paginate_orphans',
                                           'django.views.generic.list.MultipleObjectMixin.get_paginator': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectMixin.get_paginator',
                                           'django.views.generic.list.MultipleObjectMixin.get_queryset': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectMixin.get_queryset',
                                           'django.views.generic.list.MultipleObjectMixin.paginate_queryset': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectMixin.paginate_queryset',
                                           'django.views.generic.list.MultipleObjectTemplateResponseMixin': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectTemplateResponseMixin',
                                           'django.views.generic.list.MultipleObjectTemplateResponseMixin.get_template_names': 'http://django.readthedocs.org/en/latest/ref/class-based-views/mixins-multiple-object.html#django.views.generic.list.MultipleObjectTemplateResponseMixin.get_template_names'},
            'django.views.i18n': { 'django.views.i18n.JSONCatalog': 'http://django.readthedocs.org/en/latest/topics/i18n/translation.html#django.views.i18n.JSONCatalog',
                                   'django.views.i18n.JavaScriptCatalog': 'http://django.readthedocs.org/en/latest/topics/i18n/translation.html#django.views.i18n.JavaScriptCatalog',
                                   'django.views.i18n.set_language': 'http://django.readthedocs.org/en/latest/topics/i18n/translation.html#django.views.i18n.set_language'},
            'django.views.static': {'django.views.static.serve': 'http://django.readthedocs.org/en/latest/ref/views.html#django.views.static.serve'}}}
